package com.slg.j2me.game;

import com.slg.j2me.lib.gfx.ImageSequence;
import java.io.DataInputStream;
import java.io.DataOutputStream;
import javax.microedition.lcdui.Graphics;
/* loaded from: classes.dex */
class AnimSprite {
    public static final int cfpDefaultFrameDuration = 6553;
    public static final int cfpDefaultFrameRate = 655360;
    public static final int eAnchorBottom = 2;
    public static final int eAnchorCentre = 0;
    public static final int eAnchorLeft = 1;
    public static final int eAnchorRight = 2;
    public static final int eAnchorTop = 1;
    public static final int flagAnimFinished = 16;
    public static final int flagAnimLooped = 8;
    public static final int flagPaused = 32;
    public static final int flagPlayBackwards = 1;
    public static final int flagPlayLoop = 2;
    public static final int flagPlayPingPong = 4;
    public static int lastBlendMode = -1;
    public byte anchorX;
    public byte anchorY;
    public int blendMode;
    public boolean flipped;
    public int fpFrameDuration;
    public int fpFrameTime;
    public int fpRot;
    public int fpScale;
    public int frame;
    public ImageSequence gfx;
    public int gfxSaveIndex;
    public int playFlags;
    public int tintColor;

    public AnimSprite() {
        reset();
    }

    public void reset() {
        this.gfx = null;
        this.frame = 0;
        this.flipped = false;
        this.fpRot = 0;
        this.fpScale = 65536;
        this.tintColor = -1;
        this.blendMode = 0;
        this.fpFrameDuration = cfpDefaultFrameDuration;
        this.fpFrameTime = 0;
        this.anchorX = (byte) 0;
        this.anchorY = (byte) 0;
        this.playFlags = 0;
    }

    public void animate(int dt) {
        this.playFlags &= -9;
        if (this.gfx != null && (this.playFlags & 48) == 0) {
            this.fpFrameTime += dt;
            if (this.fpFrameTime >= this.fpFrameDuration) {
                this.fpFrameTime -= this.fpFrameDuration;
                if (this.fpFrameTime >= this.fpFrameDuration) {
                    this.fpFrameTime = 0;
                }
                if ((this.playFlags & 1) != 0) {
                    this.frame--;
                    if (this.frame < 0) {
                        if ((this.playFlags & 4) != 0) {
                            this.frame += 2;
                            this.playFlags &= -2;
                            this.playFlags |= 8;
                            return;
                        } else if ((this.playFlags & 2) != 0) {
                            this.frame = this.gfx.numFrames - 1;
                            this.playFlags |= 8;
                            return;
                        } else {
                            this.frame = 0;
                            this.playFlags |= 16;
                            return;
                        }
                    }
                    return;
                }
                this.frame++;
                if (this.frame >= this.gfx.numFrames) {
                    if ((this.playFlags & 4) != 0) {
                        this.frame -= 2;
                        this.playFlags |= 1;
                    } else if ((this.playFlags & 2) != 0) {
                        this.frame = 0;
                        this.playFlags |= 8;
                    } else {
                        this.frame = this.gfx.numFrames - 1;
                        this.playFlags |= 16;
                    }
                }
            }
        }
    }

    public void paint(Graphics g, int sx, int sy) {
        if (this.gfx != null) {
            int w = this.gfx.getRectWidth(this.frame);
            int h = this.gfx.getRectHeight(this.frame);
            g.setBlendColor(this.tintColor);
            if (lastBlendMode != this.blendMode) {
                g.setBlendMode(this.blendMode);
                lastBlendMode = this.blendMode;
            }
            if (this.fpRot == 0 && this.fpScale == 65536) {
                if (this.anchorX == 0) {
                    sx -= w >> 1;
                } else {
                    if ((this.anchorX == 2) != this.flipped) {
                        sx -= w;
                    }
                }
                if (this.anchorY == 0) {
                    sy -= h >> 1;
                } else if (this.anchorY == 2) {
                    sy -= h;
                }
                this.gfx.drawImageTrans(g, this.frame, sx, sy, this.flipped ? 1 : 0);
            } else if (this.fpRot == 0) {
                this.gfx.drawImageScaled(g, this.frame, sx, sy, this.fpScale, this.flipped ? 1 : 0);
            } else {
                this.gfx.drawImageRotated(g, this.frame, sx, sy, this.fpRot, this.fpScale, this.flipped ? 1 : 0);
            }
        }
    }

    public void startAnim(ImageSequence _gfx, int _gfxSaveIndex, boolean loop, boolean pingPong, int fpRateScale) {
        this.gfx = _gfx;
        this.gfxSaveIndex = _gfxSaveIndex;
        this.frame = 0;
        this.flipped = false;
        this.anchorX = (byte) 0;
        this.anchorY = (byte) 0;
        this.playFlags = loop ? 2 : 0;
        this.playFlags |= pingPong ? 4 : 0;
        this.fpFrameDuration = fpRateScale == 65536 ? cfpDefaultFrameDuration : (int) (429457408 / fpRateScale);
        if (this.gfx.numFrames < 2) {
            this.playFlags &= -5;
        }
    }

    public void pause(boolean p) {
        if (p) {
            this.playFlags |= 32;
        } else {
            this.playFlags &= -33;
        }
    }

    public boolean isPaused() {
        return (this.playFlags & 32) != 0;
    }

    public void setFrame(int n) {
        if (this.gfx != null && n < this.gfx.numFrames) {
            this.frame = n;
            this.fpFrameTime = 0;
        }
    }

    public static void resetTintColor(Graphics g) {
        g.setBlendColor(-1);
        g.setBlendMode(0);
        lastBlendMode = 0;
    }

    public void saveState(DataOutputStream outputStream) {
        try {
            outputStream.writeInt(this.gfxSaveIndex);
            outputStream.writeInt(this.frame);
            outputStream.writeInt(this.flipped ? 1 : 0);
            outputStream.writeInt(this.fpRot);
            outputStream.writeInt(this.fpScale);
            outputStream.writeInt(this.tintColor);
            outputStream.writeInt(this.blendMode);
            outputStream.writeInt(this.fpFrameDuration);
            outputStream.writeInt(this.fpFrameTime);
            outputStream.writeInt(this.anchorX);
            outputStream.writeInt(this.anchorY);
            outputStream.writeInt(this.playFlags);
        } catch (Exception e) {
        }
    }

    public void loadState(DataInputStream inputStream, ImageSequence[] gfxTable) {
        try {
            this.gfxSaveIndex = inputStream.readInt();
            this.gfx = gfxTable[this.gfxSaveIndex];
            this.frame = inputStream.readInt();
            this.flipped = inputStream.readInt() != 0;
            this.fpRot = inputStream.readInt();
            this.fpScale = inputStream.readInt();
            this.tintColor = inputStream.readInt();
            this.blendMode = inputStream.readInt();
            this.fpFrameDuration = inputStream.readInt();
            this.fpFrameTime = inputStream.readInt();
            this.anchorX = (byte) inputStream.readInt();
            this.anchorY = (byte) inputStream.readInt();
            this.playFlags = inputStream.readInt();
        } catch (Exception e) {
        }
    }
}
