package com.slg.j2me.game;

import com.ju6.mms.pdu.CharacterSets;
import com.slg.j2me.lib.snd.SoundBank;
import com.slg.j2me.lib.sys.FixedPoint;
import com.slg.j2me.lib.util.Rand;
import java.io.DataInputStream;
import java.io.DataOutputStream;
import java.lang.reflect.Array;
/* JADX INFO: Access modifiers changed from: package-private */
/* loaded from: classes.dex */
public class GameLogic {
    public static final int cCalibrateCountdownValue = 3;
    public static final int cKillChainLevel1 = 10;
    public static final int cKillChainLevel2 = 20;
    public static final int cKillChainLevel3 = 30;
    public static final int cKillChainMultiplier1 = 2;
    public static final int cKillChainMultiplier2 = 4;
    public static final int cKillChainMultiplier3 = 8;
    public static final int cMaxGameObj = 100;
    public static final int cfpCameraTrackAheadTime = 16384;
    public static final int cfpControlTiltDeadZone = 0;
    public static final int cfpDeadSharkFadeRate = 32768;
    public static final int cfpDeadSharkFadeTime = 131072;
    public static final int cfpGameOverFadeTime = 262144;
    public static final int cfpGameOverPauseBeforeShowScore = 65536;
    public static final int cfpGravity = 4587520;
    public static final int cfpIntroFadeRate = 87381;
    public static final int cfpIntroFadeTime = 49152;
    private static final int cfpMaxRot = 1048576;
    private static final int cfpMaxRotCharged = 2097152;
    private static final int cfpMaxRotFilterRate = 4194304;
    public static final int cfpSharkDropHeightEnd = 0;
    public static final int cfpSharkDropHeightStart = -786432;
    public static final int cfpSharkMaxFallRate = 1048576;
    public static final int eAchAverageScore = 3;
    public static final int eAchAverageTime = 4;
    public static final int eAchHighScore = 1;
    public static final int eAchLastScore = 2;
    public static final int eAchMaxBonusItems = 6;
    public static final int eAchMaxShark = 8;
    public static final int eAchMaxStreak = 9;
    public static final int eAchNumPlayed = 0;
    public static final int eAchTotalEats = 7;
    public static final int eAchTotalTime = 5;
    public static final int eDrawOrderDefault = 0;
    public static final int eDrawOrderJellyfish = 2;
    public static final int eDrawOrderProjectile = 4;
    public static final int eDrawOrderSardine = 1;
    public static final int eDrawOrderShark = 5;
    public static final int eDrawOrderTuna = 3;
    public static final int eMaxDrawOrder = 6;
    public static final int eMultiKillAnglerfish = 2;
    public static final int eMultiKillBarracuda = 0;
    public static final int eMultiKillBlobfish = 3;
    public static final int eMultiKillBlowfish = 1;
    public static final int eMultiKillPelican = 4;
    public static final int eMultiKillTropical = 5;
    public static final int eNumAchs = 10;
    public static final int eNumMultiKillTypes = 6;
    public static final int eStateGameOver = 3;
    public static final int eStateGameOverOnMenu = 2;
    public static final int eStateGameOverShowScore = 1;
    public static final int eStateGameOverStartFade = 0;
    public static final int eStateGameplay = 2;
    public static final int eStateIntro = 1;
    public static final int eStateIntroCalibrate = 0;
    public static final int eStateIntroDropping = 2;
    public static final int eStateIntroFadeIn = 1;
    public static final int eStateNone = 0;
    public static Rand random;
    public int calibrateCounter;
    private int fpCameraStartPosBlend;
    private int fpFilteredMaxRot;
    public int fpGameStateTime;
    private int fpLastDesiredSpeed;
    public int fpPlayerKillChainTimer;
    public int gameState;
    public int gameSubState;
    private boolean lockCameraToStartPos;
    public int playerBestStreakScore;
    public int playerKillChain;
    public int playerScore;
    public int playerStreakStartScore;
    public int scoreMultiplier;
    public static final int cfpCalibrateCountdownTime = FixedPoint.stringToFP("0.75");
    public static final int cfpGameOverFadeLevel = FixedPoint.stringToFP("0.6");
    public static final int cfpGameOverFadeRate = (int) ((cfpGameOverFadeLevel << 16) / 262144);
    public static final int cfpCameraBlendSpeed = FixedPoint.stringToFP("32");
    public static final int cfpCullSpawnerRange = FixedPoint.stringToFP("2.0");
    public static final int cfpActivateSpawnerRange = FixedPoint.stringToFP("1.5");
    private static final int cfpBreachDampingX = FixedPoint.stringToFP("0.95");
    public static final int cfpKillChainTimeLimit = FixedPoint.stringToFP("3");
    public static final int cfpKillChainTimeLimitMax = FixedPoint.stringToFP("4");
    public static Spawner spawner = null;
    public static Water water = null;
    public static GameObj player = null;
    public static int[] multiKillCount = {3, 2, 3, 3, 3, 4};
    public static int[] multiKillTimeLimit = {5000, 4000, 5000, 5000, 3000, 3500};
    public static int[] rankingScores = {0, CharacterSets.UCS2, 2000, 3000, 4000, 6000, 10000, 15000, 20000, 25000, 30000, 40000, 50000, 60000, 70000, 80000, 90000, 100000, 150000};
    public static int[] achievements = new int[10];
    public static boolean firstTimeCalibrate = true;
    public int fpControlTiltX = 0;
    public int fpControlTiltY = 0;
    public int fpControlSensitivity = 65536;
    private boolean gameObjSlotsAllocated = false;
    private GameObj[] gameObjSlots = new GameObj[100];
    public GameObj[] gameObjList = new GameObj[100];
    public GameObj[][] gameObjDrawList = (GameObj[][]) Array.newInstance(GameObj.class, 6, 100);
    public int numGameObj = 0;
    public int[] numDrawObj = new int[6];
    public int gameTime = 0;
    public int fpCameraOffsetX = 0;
    public int fpCameraOffsetY = 0;
    public int fpCameraPosX = 0;
    public int fpCameraPosY = 0;
    public int[] rectVisible = new int[4];
    public int[] rectCullSpawner = new int[4];
    public int[] rectActivateSpawner = new int[4];
    public int[][] multiKillTimes = new int[6];
    public int[] multiKillNextIndex = new int[6];
    public int[] npcNumActive = new int[25];
    public int[] npcNumKilled = new int[25];

    public GameLogic() {
        random = new Rand();
        int seed = (int) System.currentTimeMillis();
        random.setSeed(seed);
        water = Water.instance;
        GameObj.game = this;
        resetGameObjs();
        Spawner.game = this;
        spawner = new Spawner();
        initScreenRects();
        for (int i = 0; i < 6; i++) {
            this.multiKillTimes[i] = new int[multiKillCount[i]];
        }
        initMultiKills();
    }

    public static int randRange(int min, int max) {
        return (Math.abs(random.val()) % ((max - min) + 1)) + min;
    }

    public static boolean randBoolean() {
        return (random.val() & 1) == 1;
    }

    public static int randAngle() {
        return random.val() & 16777215;
    }

    public void newGame() {
        resetGameObjs();
        SoundBank.sfxClearSavedLoops();
        this.playerScore = 0;
        this.playerKillChain = 0;
        this.fpPlayerKillChainTimer = 0;
        this.playerStreakStartScore = 0;
        this.playerBestStreakScore = 0;
        this.scoreMultiplier = 1;
        this.gameTime = 0;
        this.gameState = 0;
        this.fpGameStateTime = 0;
        this.fpLastDesiredSpeed = 0;
        for (int i = 0; i < 25; i++) {
            this.npcNumActive[i] = 0;
            this.npcNumKilled[i] = 0;
        }
        GameScreen gameScreen = GameApp.gameScreen;
        TiledLevel tl = GameScreen.tiledLevel;
        tl.createSpawners();
        player.fpPos[0] = tl.fpPlayerStartX;
        player.fpPos[1] = tl.fpPlayerStartY;
        initScreenRects();
        initMultiKills();
        updateCamera();
        player.nextAnimState(2);
        player.refreshMouthPos();
        player.initBasicExtents();
        this.fpFilteredMaxRot = 1048576;
        spawner.addSpawner(19, cfpMaxRotFilterRate, 0);
        nextGameState(1);
    }

    public void initGame() {
    }

    public void initScreenRects() {
        this.rectVisible[0] = 0;
        this.rectVisible[1] = 0;
        this.rectVisible[2] = TiledLevel.cfpDisplayWidthMetres;
        this.rectVisible[3] = TiledLevel.cfpDisplayHeightMetres;
        this.rectCullSpawner[0] = 0;
        this.rectCullSpawner[1] = 0;
        this.rectCullSpawner[2] = ((TiledLevel.cfpDisplayWidthMetres ^ cfpCullSpawnerRange) & 134217728) != 0 ? -((int) (((-TiledLevel.cfpDisplayWidthMetres) * cfpCullSpawnerRange) >> 16)) : (int) ((TiledLevel.cfpDisplayWidthMetres * cfpCullSpawnerRange) >> 16);
        this.rectCullSpawner[3] = ((TiledLevel.cfpDisplayHeightMetres ^ cfpCullSpawnerRange) & 134217728) != 0 ? -((int) (((-TiledLevel.cfpDisplayHeightMetres) * cfpCullSpawnerRange) >> 16)) : (int) ((TiledLevel.cfpDisplayHeightMetres * cfpCullSpawnerRange) >> 16);
        this.rectActivateSpawner[0] = 0;
        this.rectActivateSpawner[1] = 0;
        this.rectActivateSpawner[2] = ((TiledLevel.cfpDisplayWidthMetres ^ cfpActivateSpawnerRange) & 134217728) != 0 ? -((int) (((-TiledLevel.cfpDisplayWidthMetres) * cfpActivateSpawnerRange) >> 16)) : (int) ((TiledLevel.cfpDisplayWidthMetres * cfpActivateSpawnerRange) >> 16);
        this.rectActivateSpawner[3] = ((TiledLevel.cfpDisplayHeightMetres ^ cfpActivateSpawnerRange) & 134217728) != 0 ? -((int) (((-TiledLevel.cfpDisplayHeightMetres) * cfpActivateSpawnerRange) >> 16)) : (int) ((TiledLevel.cfpDisplayHeightMetres * cfpActivateSpawnerRange) >> 16);
    }

    private void resetGameObjs() {
        if (!this.gameObjSlotsAllocated) {
            for (int i = 0; i < 100; i++) {
                this.gameObjSlots[i] = new GameObj();
            }
            this.gameObjSlotsAllocated = true;
        }
        for (int i2 = 0; i2 < 100; i2++) {
            this.gameObjList[i2] = null;
            this.gameObjSlots[i2].allocated = false;
            this.gameObjSlots[i2].deleted = false;
            this.gameObjSlots[i2].reset();
        }
        this.numGameObj = 0;
        for (int i3 = 0; i3 < 6; i3++) {
            this.numDrawObj[i3] = 0;
        }
        player = allocateGameObj();
        player.initPlayer();
    }

    public GameObj allocateGameObj() {
        for (int i = 0; i < 100; i++) {
            GameObj obj = this.gameObjSlots[i];
            if (!obj.allocated) {
                obj.allocated = true;
                GameObj[] gameObjArr = this.gameObjList;
                int i2 = this.numGameObj;
                this.numGameObj = i2 + 1;
                gameObjArr[i2] = obj;
                obj.allocIndex = i;
                obj.reset();
                return obj;
            }
        }
        return null;
    }

    private void refreshGameObjList() {
        this.numGameObj = 0;
        for (int i = 0; i < 6; i++) {
            this.numDrawObj[i] = 0;
        }
        for (int i2 = 0; i2 < 100; i2++) {
            GameObj obj = this.gameObjSlots[i2];
            if (obj.deleted) {
                obj.allocated = false;
                obj.deleted = false;
            }
            if (obj.allocated) {
                GameObj[] gameObjArr = this.gameObjList;
                int i3 = this.numGameObj;
                this.numGameObj = i3 + 1;
                gameObjArr[i3] = obj;
                int drawBucket = 0;
                switch (obj.animSet) {
                    case 0:
                        drawBucket = 5;
                        break;
                    case 2:
                        drawBucket = 3;
                        break;
                    case 4:
                        drawBucket = 1;
                        break;
                    case 6:
                        drawBucket = 2;
                        break;
                    case 19:
                    case 20:
                        drawBucket = 4;
                        break;
                }
                GameObj[] gameObjArr2 = this.gameObjDrawList[drawBucket];
                int[] iArr = this.numDrawObj;
                int i4 = iArr[drawBucket];
                iArr[drawBucket] = i4 + 1;
                gameObjArr2[i4] = obj;
            }
        }
    }

    public void initMultiKills() {
        for (int i = 0; i < 6; i++) {
            for (int j = 0; j < multiKillCount[i]; j++) {
                this.multiKillTimes[i][j] = 0;
            }
            this.multiKillNextIndex[i] = 0;
        }
    }

    public boolean updateMultiKill(int n) {
        int idx = this.multiKillNextIndex[n];
        int[] times = this.multiKillTimes[n];
        int count = multiKillCount[n];
        int limit = multiKillTimeLimit[n];
        int[] iArr = this.multiKillNextIndex;
        iArr[n] = iArr[n] + 1;
        int[] iArr2 = this.multiKillNextIndex;
        iArr2[n] = iArr2[n] % count;
        times[idx] = this.gameTime;
        int oldestTime = times[this.multiKillNextIndex[n]];
        boolean pass = this.gameTime - oldestTime <= limit;
        if (pass) {
            for (int i = 0; i < count; i++) {
                times[i] = 0;
            }
        }
        return pass;
    }

    public void updateKillChain() {
        int old = this.scoreMultiplier;
        int maxKillChain = 30;
        if (GameObj.sharkLevel < 3) {
            maxKillChain = 10;
        } else if (GameObj.sharkLevel < 6) {
            maxKillChain = 20;
        }
        int timeLimit = cfpKillChainTimeLimit;
        if (GameObj.sharkLevel == 9) {
            timeLimit = cfpKillChainTimeLimitMax;
        }
        if (this.playerKillChain < maxKillChain) {
            this.playerKillChain++;
        }
        this.fpPlayerKillChainTimer = timeLimit;
        if (this.playerKillChain >= 30) {
            this.scoreMultiplier = 8;
        } else if (this.playerKillChain >= 20) {
            this.scoreMultiplier = 4;
        } else if (this.playerKillChain >= 10) {
            this.scoreMultiplier = 2;
        } else {
            this.scoreMultiplier = 1;
        }
        if (this.scoreMultiplier != old) {
            int sfx = -1;
            if (this.scoreMultiplier > 1) {
                String str = null;
                switch (this.scoreMultiplier) {
                    case 2:
                        str = "BINGE BONUS";
                        sfx = 20;
                        break;
                    case 4:
                        str = "CHOMP FEST";
                        sfx = 23;
                        break;
                    case 8:
                        str = "MEGA MUNCH";
                        sfx = 24;
                        break;
                }
                GameApp.gameScreen.addEatTextMessageFixed(str, -1);
                if (old == 1) {
                    this.playerStreakStartScore = this.playerScore;
                }
            } else {
                sfx = 22;
            }
            if (sfx != -1) {
                SoundBank.sfxPlay(sfx, false, 100, 0);
            }
        }
    }

    public void resetKillChain() {
        int streakScore;
        if (this.scoreMultiplier > 1 && (streakScore = this.playerScore - this.playerStreakStartScore) > this.playerBestStreakScore) {
            this.playerBestStreakScore = streakScore;
        }
        this.fpPlayerKillChainTimer = 0;
        this.playerKillChain = 0;
        this.scoreMultiplier = 1;
    }

    public void process() {
        this.gameTime += GameApp.lastFrameTime;
        refreshControlTilt();
        updateGameState();
        updateCamera();
        refreshGameObjList();
    }

    public void refreshControlTilt() {
        this.fpControlTiltX = (int) (GameApp.sensorTilt[0] * 65536.0f);
        this.fpControlTiltY = (int) (GameApp.sensorTilt[1] * 65536.0f);
        if (this.fpControlTiltX > 0 && this.fpControlTiltX < 0) {
            this.fpControlTiltX = 0;
        } else if (this.fpControlTiltX < 0 && this.fpControlTiltX > 0) {
            this.fpControlTiltX = 0;
        }
        if (this.fpControlTiltY > 0 && this.fpControlTiltY < 0) {
            this.fpControlTiltY = 0;
        } else if (this.fpControlTiltY < 0 && this.fpControlTiltY > 0) {
            this.fpControlTiltY = 0;
        }
    }

    public void updatePlayerMovement() {
        int i;
        int i2;
        int fpDirX;
        int i3;
        int dt = GameApp.fp_deltatime;
        if (dt >= 6553) {
            dt = 6553;
        }
        boolean charged = GameObj.fpPlayerChargeFactor > 0;
        int[][] iArr = GameObj.sharkTable;
        GameObj gameObj = player;
        int fpDesiredSpeed = iArr[GameObj.sharkLevel][5];
        int fpMinSpeed = 131072;
        if (charged) {
            fpDesiredSpeed += ((GameObj.fpPlayerChargeScale ^ fpDesiredSpeed) & 134217728) != 0 ? -((int) (((-fpDesiredSpeed) * GameObj.fpPlayerChargeScale) >> 16)) : (int) ((fpDesiredSpeed * GameObj.fpPlayerChargeScale) >> 16);
            if (((GameObj.fpPlayerChargeScale ^ 131072) & 134217728) != 0) {
                i3 = -((int) (((-131072) * GameObj.fpPlayerChargeScale) >> 16));
            } else {
                i3 = (int) ((131072 * GameObj.fpPlayerChargeScale) >> 16);
            }
            fpMinSpeed = 131072 + i3;
        }
        boolean aboveWater = player.fpPos[1] < GameObj.cfpWaterHeight;
        if (player.animState == 7) {
            int step = ((524288 ^ dt) & 134217728) != 0 ? -((int) (((-524288) * dt) >> 16)) : (int) ((524288 * dt) >> 16);
            if (aboveWater) {
                player.fpVel[0] = ((player.fpVel[0] ^ cfpBreachDampingX) & 134217728) != 0 ? -((int) (((-player.fpVel[0]) * cfpBreachDampingX) >> 16)) : (int) ((player.fpVel[0] * cfpBreachDampingX) >> 16);
                int[] iArr2 = player.fpVel;
                iArr2[1] = iArr2[1] + (((4587520 ^ dt) & 134217728) != 0 ? -((int) (((-4587520) * dt) >> 16)) : (int) ((4587520 * dt) >> 16));
            } else {
                player.fpVel[0] = moveValueWithDamping(player.fpVel[0], 0, step, 524288, 8192);
                int[] iArr3 = player.fpVel;
                int i4 = player.fpVel[1];
                GameObj gameObj2 = player;
                iArr3[1] = moveValueWithDamping(i4, GameObj.fpPlayerDeathFallSpeed, step, 524288, 8192);
            }
            if (player.fpFadeAlpha == 0) {
                GameObj gameObj3 = player;
                GameObj gameObj4 = player;
                GameObj.fpPlayerDeathFallSpeed = moveValue(GameObj.fpPlayerDeathFallSpeed, 0, step >> 2);
                return;
            }
            return;
        }
        if (player.animState == 6) {
            if (aboveWater) {
                player.fpVel[0] = ((player.fpVel[0] ^ cfpBreachDampingX) & 134217728) != 0 ? -((int) (((-player.fpVel[0]) * cfpBreachDampingX) >> 16)) : (int) ((player.fpVel[0] * cfpBreachDampingX) >> 16);
                int[] iArr4 = player.fpVel;
                iArr4[1] = iArr4[1] + (((4587520 ^ dt) & 134217728) != 0 ? -((int) (((-4587520) * dt) >> 16)) : (int) ((4587520 * dt) >> 16));
            } else {
                int step2 = ((524288 ^ dt) & 134217728) != 0 ? -((int) (((-524288) * dt) >> 16)) : (int) ((524288 * dt) >> 16);
                player.fpVel[0] = moveValueWithDamping(player.fpVel[0], 0, step2, 524288, 8192);
                player.fpVel[1] = moveValueWithDamping(player.fpVel[1], 0, step2, 524288, 8192);
                return;
            }
        }
        if (GameObj.playerNumShakesRequired > 0) {
            fpDesiredSpeed = ((GameObj.fpPlayerShakeSpeedScale ^ fpDesiredSpeed) & 134217728) != 0 ? -((int) (((-fpDesiredSpeed) * GameObj.fpPlayerShakeSpeedScale) >> 16)) : (int) ((fpDesiredSpeed * GameObj.fpPlayerShakeSpeedScale) >> 16);
        } else if (GameObj.fpPlayerPoisonTimeRemaining > 0) {
            fpDesiredSpeed >>= 1;
        }
        int fpDesiredSpeed2 = moveValue(this.fpLastDesiredSpeed, fpDesiredSpeed, ((2097152 ^ dt) & 134217728) != 0 ? -((int) (((-2097152) * dt) >> 16)) : (int) ((2097152 * dt) >> 16));
        this.fpLastDesiredSpeed = fpDesiredSpeed2;
        int fpAccel = fpDesiredSpeed2 << 4;
        int fpSensitivity = 65536 + this.fpControlSensitivity;
        if ((((this.fpControlTiltX ^ fpSensitivity) & 134217728) != 0 ? -((int) (((-this.fpControlTiltX) * fpSensitivity) >> 16)) : (int) ((this.fpControlTiltX * fpSensitivity) >> 16)) < -8192) {
            i = -8192;
        } else {
            i = (((this.fpControlTiltX ^ fpSensitivity) & 134217728) != 0 ? -((int) ((((long) (-this.fpControlTiltX)) * ((long) fpSensitivity)) >> 16)) : (int) ((((long) this.fpControlTiltX) * ((long) fpSensitivity)) >> 16)) > 8192 ? 8192 : ((this.fpControlTiltX ^ fpSensitivity) & 134217728) != 0 ? -((int) (((-this.fpControlTiltX) * fpSensitivity) >> 16)) : (int) ((this.fpControlTiltX * fpSensitivity) >> 16);
        }
        int fpTiltX = i << 3;
        if ((((this.fpControlTiltY ^ fpSensitivity) & 134217728) != 0 ? -((int) (((-this.fpControlTiltY) * fpSensitivity) >> 16)) : (int) ((this.fpControlTiltY * fpSensitivity) >> 16)) < -8192) {
            i2 = -8192;
        } else {
            i2 = (((this.fpControlTiltY ^ fpSensitivity) & 134217728) != 0 ? -((int) ((((long) (-this.fpControlTiltY)) * ((long) fpSensitivity)) >> 16)) : (int) ((((long) this.fpControlTiltY) * ((long) fpSensitivity)) >> 16)) > 8192 ? 8192 : ((this.fpControlTiltY ^ fpSensitivity) & 134217728) != 0 ? -((int) (((-this.fpControlTiltY) * fpSensitivity) >> 16)) : (int) ((this.fpControlTiltY * fpSensitivity) >> 16);
        }
        int fpTiltY = i2 << 3;
        int fpDesiredVelX = ((fpTiltX ^ fpDesiredSpeed2) & 134217728) != 0 ? -((int) (((-fpTiltX) * fpDesiredSpeed2) >> 16)) : (int) ((fpTiltX * fpDesiredSpeed2) >> 16);
        int fpDesiredVelY = (((-fpTiltY) ^ fpDesiredSpeed2) & 134217728) != 0 ? -((int) (((-(-fpTiltY)) * fpDesiredSpeed2) >> 16)) : (int) (((-fpTiltY) * fpDesiredSpeed2) >> 16);
        if (fpDesiredVelX < fpMinSpeed) {
            if (fpDesiredVelX >= (-fpMinSpeed)) {
                fpDesiredVelX = -fpMinSpeed;
            }
        } else if (fpDesiredVelX <= fpMinSpeed) {
            fpDesiredVelX = fpMinSpeed;
        }
        if (!charged) {
            int fpAbsY = fpDesiredVelY < 0 ? -fpDesiredVelY : fpDesiredVelY;
            if (fpDesiredVelX < 0) {
                if (fpDesiredVelX >= (-fpAbsY)) {
                    fpDesiredVelX = -fpAbsY;
                }
            } else if (fpDesiredVelX <= fpAbsY) {
                fpDesiredVelX = fpAbsY;
            }
        }
        int collReactBlend = player.fpCollReactBlend;
        boolean disableGravity = collReactBlend > 49152;
        if (collReactBlend > 0) {
            int collReactBlend2 = 65536 < (collReactBlend << 1) ? 65536 : collReactBlend << 1;
            fpDesiredVelX = FixedPoint.linearInterpolate(collReactBlend2, fpDesiredVelX, player.fpVel[0]);
            fpDesiredVelY = FixedPoint.linearInterpolate(collReactBlend2, fpDesiredVelY, player.fpVel[1]);
        }
        int fpVelAdd = ((fpAccel ^ dt) & 134217728) != 0 ? -((int) (((-fpAccel) * dt) >> 16)) : (int) ((fpAccel * dt) >> 16);
        if (player.animState == 3) {
            fpVelAdd >>= 2;
        }
        if (aboveWater) {
            if (!disableGravity) {
                if (!GameObj.playerBeached) {
                    player.fpVel[0] = ((player.fpVel[0] ^ cfpBreachDampingX) & 134217728) != 0 ? -((int) (((-player.fpVel[0]) * cfpBreachDampingX) >> 16)) : (int) ((player.fpVel[0] * cfpBreachDampingX) >> 16);
                }
                int[] iArr5 = player.fpVel;
                iArr5[1] = iArr5[1] + (((4587520 ^ dt) & 134217728) != 0 ? -((int) (((-4587520) * dt) >> 16)) : (int) ((4587520 * dt) >> 16));
            }
            fpDesiredVelX = player.fpVel[0];
            fpDesiredVelY = player.fpVel[1];
        } else {
            if (GameObj.fpPlayerNoBreachTimer > 0) {
                fpVelAdd >>= 2;
            }
            player.fpVel[0] = moveValueWithDamping(player.fpVel[0], fpDesiredVelX, fpVelAdd, 524288, 8192);
            player.fpVel[1] = moveValueWithDamping(player.fpVel[1], fpDesiredVelY, fpVelAdd, 524288, 8192);
        }
        if (player.animState == 2) {
            boolean isFacingLeft = fpDesiredVelX < 0;
            if (player.facingLeft != isFacingLeft) {
                player.nextAnimState(3);
            }
        }
        GameObj gameObj5 = player;
        int[] iArr6 = GameObj.fpPlayerRotCalcVel;
        GameObj gameObj6 = player;
        iArr6[0] = moveValueWithDamping(GameObj.fpPlayerRotCalcVel[0], fpDesiredVelX << 0, fpVelAdd, 524288, 8192);
        GameObj gameObj7 = player;
        int[] iArr7 = GameObj.fpPlayerRotCalcVel;
        GameObj gameObj8 = player;
        iArr7[1] = moveValueWithDamping(GameObj.fpPlayerRotCalcVel[1], fpDesiredVelY, fpVelAdd, 524288, 8192);
        GameObj gameObj9 = player;
        int vx = GameObj.fpPlayerRotCalcVel[0];
        GameObj gameObj10 = player;
        int vy = GameObj.fpPlayerRotCalcVel[1];
        int fpSpeed = FixedPoint.sqrt_bits((((vx ^ vx) & 134217728) != 0 ? -((int) (((-vx) * vx) >> 16)) : (int) ((vx * vx) >> 16)) + (((vy ^ vy) & 134217728) != 0 ? -((int) (((-vy) * vy) >> 16)) : (int) ((vy * vy) >> 16)));
        if (fpSpeed <= 0) {
            fpDirX = 0;
        } else {
            fpDirX = (int) ((vx << 16) / fpSpeed);
        }
        int fpAng = cfpMaxRotFilterRate - FixedPoint.asinLut(fpDirX);
        if (vx < 0) {
            fpAng = GameObj.cfpDynamiteRotSpeedWater - fpAng;
        }
        int fpMaxRot = this.fpFilteredMaxRot;
        int fpDesiredRot = charged ? 2097152 : 1048576;
        this.fpFilteredMaxRot = moveValueWithDamping(this.fpFilteredMaxRot, fpDesiredRot, ((cfpMaxRotFilterRate ^ dt) & 134217728) != 0 ? -((int) (((-4194304) * dt) >> 16)) : (int) ((4194304 * dt) >> 16), cfpMaxRotFilterRate, 8192);
        if (fpAng >= fpMaxRot) {
            fpAng = fpMaxRot;
        }
        if (vy > 0) {
            fpAng = -fpAng;
        }
        if (!player.facingLeft) {
            fpAng = -fpAng;
        }
        int fpAng2 = fpAng & 16777215;
        if (player.animState == 3) {
            fpAng2 = 0;
        }
        player.fpRot = moveAngleWithDamping(player.fpRot, fpAng2, ((cfpMaxRotFilterRate ^ dt) & 134217728) != 0 ? -((int) (((-4194304) * dt) >> 16)) : (int) ((4194304 * dt) >> 16), 1048576, 8192);
    }

    private void updateGameObjects() {
        for (int i = 0; i < this.numGameObj; i++) {
            this.gameObjList[i].process();
        }
    }

    private void updateCamera() {
        int i;
        int camX;
        int camY;
        int fpTrackTime = 16384;
        if (GameObj.fpPlayerChargeFactor > 0) {
            fpTrackTime = (int) ((16384 << 16) / (GameObj.fpPlayerChargeScale + 65536));
        }
        int fpOffsetX = ((player.fpVel[0] ^ fpTrackTime) & 134217728) != 0 ? -((int) (((-fpTrackTime) * player.fpVel[0]) >> 16)) : (int) ((fpTrackTime * player.fpVel[0]) >> 16);
        int fpOffsetY = ((player.fpVel[1] ^ fpTrackTime) & 134217728) != 0 ? -((int) (((-fpTrackTime) * player.fpVel[1]) >> 16)) : (int) ((fpTrackTime * player.fpVel[1]) >> 16);
        int fpBlend = ((cfpCameraBlendSpeed ^ GameApp.fp_deltatime) & 134217728) != 0 ? -((int) (((-cfpCameraBlendSpeed) * GameApp.fp_deltatime) >> 16)) : (int) ((cfpCameraBlendSpeed * GameApp.fp_deltatime) >> 16);
        this.fpCameraOffsetX = moveValueWithDamping(this.fpCameraOffsetX, fpOffsetX, fpBlend, 524288, 8192);
        this.fpCameraOffsetY = moveValueWithDamping(this.fpCameraOffsetY, fpOffsetY, fpBlend, 524288, 8192);
        this.fpCameraPosX = player.fpPos[0];
        this.fpCameraPosY = player.fpPos[1];
        if (this.fpCameraStartPosBlend < 65536) {
            this.fpCameraPosY = ((this.fpCameraStartPosBlend ^ player.fpPos[1]) & 134217728) != 0 ? -((int) (((-this.fpCameraStartPosBlend) * player.fpPos[1]) >> 16)) : (int) ((this.fpCameraStartPosBlend * player.fpPos[1]) >> 16);
            this.fpCameraOffsetY = ((this.fpCameraStartPosBlend ^ this.fpCameraOffsetY) & 134217728) != 0 ? -((int) (((-this.fpCameraStartPosBlend) * this.fpCameraOffsetY) >> 16)) : (int) ((this.fpCameraStartPosBlend * this.fpCameraOffsetY) >> 16);
        }
        if (this.lockCameraToStartPos) {
            if (player.fpPos[1] > GameObj.cfpWaterHeight) {
                this.lockCameraToStartPos = false;
            }
        } else if (this.fpCameraStartPosBlend < 65536) {
            if (65536 < this.fpCameraStartPosBlend + (((65536 ^ GameApp.fp_deltatime) & 134217728) != 0 ? -((int) (((-65536) * GameApp.fp_deltatime) >> 16)) : (int) ((65536 * GameApp.fp_deltatime) >> 16))) {
                i = 65536;
            } else {
                i = this.fpCameraStartPosBlend + (((65536 ^ GameApp.fp_deltatime) & 134217728) != 0 ? -((int) (((-65536) * GameApp.fp_deltatime) >> 16)) : (int) ((65536 * GameApp.fp_deltatime) >> 16));
            }
            this.fpCameraStartPosBlend = i;
        }
        if (this.fpCameraPosX + this.fpCameraOffsetX < 0) {
            camX = 0;
        } else {
            camX = this.fpCameraPosX + this.fpCameraOffsetX > TiledLevel.fpWorldCameraMaxX ? TiledLevel.fpWorldCameraMaxX : this.fpCameraPosX + this.fpCameraOffsetX;
        }
        if (this.fpCameraPosY + this.fpCameraOffsetY < 0) {
            camY = 0;
        } else {
            camY = this.fpCameraPosY + this.fpCameraOffsetY > TiledLevel.fpWorldCameraMaxY ? TiledLevel.fpWorldCameraMaxY : this.fpCameraPosY + this.fpCameraOffsetY;
        }
        TiledLevel.fpGameCameraX = camX;
        TiledLevel.fpGameCameraY = camY;
        this.rectVisible[0] = camX - (this.rectVisible[2] >> 1);
        this.rectVisible[1] = camY - (this.rectVisible[3] >> 1);
        this.rectCullSpawner[0] = camX - (this.rectCullSpawner[2] >> 1);
        this.rectCullSpawner[1] = camY - (this.rectCullSpawner[3] >> 1);
        this.rectActivateSpawner[0] = camX - (this.rectActivateSpawner[2] >> 1);
        this.rectActivateSpawner[1] = camY - (this.rectActivateSpawner[3] >> 1);
    }

    public static int moveValue(int from, int to, int step) {
        return to > from ? from + step < to ? from + step : to : from - step > to ? from - step : to;
    }

    public static int moveValueWithDamping(int from, int to, int step, int dampingRange, int fpMaxDampingScale) {
        if (to > from) {
            if (to - from < dampingRange) {
                int slowdown = (int) (((to - from) << 16) / dampingRange);
                if (slowdown < fpMaxDampingScale) {
                    slowdown = fpMaxDampingScale;
                } else if (slowdown > 65536) {
                    slowdown = 65536;
                }
                step = ((step ^ slowdown) & 134217728) != 0 ? -((int) (((-step) * slowdown) >> 16)) : (int) ((step * slowdown) >> 16);
            }
            return from + step < to ? from + step : to;
        } else if (to < from) {
            if (from - to < dampingRange) {
                int slowdown2 = (int) (((from - to) << 16) / dampingRange);
                if (slowdown2 < fpMaxDampingScale) {
                    slowdown2 = fpMaxDampingScale;
                } else if (slowdown2 > 65536) {
                    slowdown2 = 65536;
                }
                step = ((step ^ slowdown2) & 134217728) != 0 ? -((int) (((-step) * slowdown2) >> 16)) : (int) ((step * slowdown2) >> 16);
            }
            return from - step > to ? from - step : to;
        } else {
            return from;
        }
    }

    public static int moveAngle(int from, int to, int step) {
        int d = (((to - from) + GameObj.cfpDynamiteRotSpeedWater) & 16777215) - GameObj.cfpDynamiteRotSpeedWater;
        int s = moveValue(0, d, step);
        return (from + s) & 16777215;
    }

    public static int moveAngleWithDamping(int from, int to, int step, int dampingRange, int fpMaxDampingScale) {
        int d = (((to - from) + GameObj.cfpDynamiteRotSpeedWater) & 16777215) - GameObj.cfpDynamiteRotSpeedWater;
        int s = moveValueWithDamping(0, d, step, dampingRange, fpMaxDampingScale);
        return (from + s) & 16777215;
    }

    public void nextGameState(int newState) {
        if (newState != this.gameState) {
            this.gameState = newState;
            this.fpGameStateTime = 0;
            switch (newState) {
                case 1:
                    GameScreen.fpFullScreenFade = 65536;
                    this.gameSubState = 0;
                    player.fpPos[1] = -786432;
                    this.fpCameraStartPosBlend = 0;
                    this.lockCameraToStartPos = true;
                    this.calibrateCounter = 3;
                    GameApp.gameScreen.setIntroText(firstTimeCalibrate ? "CALIBRATING" : "GET READY", this.calibrateCounter, true);
                    GameScreen.randDeathMsg = randRange(0, 2);
                    return;
                case 2:
                default:
                    return;
                case 3:
                    GameScreen.fpGameFade = 0;
                    this.gameSubState = 0;
                    GameApp.gameScreen.setIntroText("", 0, false);
                    return;
            }
        }
    }

    public void updateGameState() {
        int dt = GameApp.fp_deltatime;
        this.fpGameStateTime += dt;
        switch (this.gameState) {
            case 1:
                updateGameObjects();
                switch (this.gameSubState) {
                    case 0:
                        if (this.fpGameStateTime > cfpCalibrateCountdownTime) {
                            this.calibrateCounter--;
                            this.fpGameStateTime = 0;
                            if (this.calibrateCounter > 0) {
                                GameApp.gameScreen.setIntroText(firstTimeCalibrate ? "CALIBRATING" : "GET READY", this.calibrateCounter, true);
                                return;
                            }
                            GameApp.gameScreen.setIntroText("GO!", 0, false);
                            this.gameSubState = 1;
                            if (firstTimeCalibrate) {
                                GameApp.calibrateSensor();
                                firstTimeCalibrate = false;
                                return;
                            }
                            return;
                        }
                        return;
                    case 1:
                        GameScreen.fpFullScreenFade -= ((87381 ^ dt) & 134217728) != 0 ? -((int) (((-87381) * dt) >> 16)) : (int) ((87381 * dt) >> 16);
                        if (GameScreen.fpFullScreenFade <= 0) {
                            GameScreen.fpFullScreenFade = 0;
                            GameScreen.fpGameFade = 0;
                            this.gameSubState = 2;
                            this.fpGameStateTime = 0;
                            GameScreen.water.slowframecount = 0;
                            return;
                        }
                        return;
                    case 2:
                        if (player.fpPos[1] >= 0) {
                            nextGameState(2);
                            return;
                        }
                        int[] iArr = player.fpVel;
                        iArr[1] = iArr[1] + (((4587520 ^ dt) & 134217728) != 0 ? -((int) (((-4587520) * dt) >> 16)) : (int) ((4587520 * dt) >> 16));
                        player.fpVel[1] = player.fpVel[1] < 1048576 ? player.fpVel[1] : 1048576;
                        return;
                    default:
                        return;
                }
            case 2:
                spawner.process();
                updatePlayerMovement();
                updateGameObjects();
                return;
            case 3:
                updatePlayerMovement();
                updateGameObjects();
                if (GameScreen.fpGameFade < cfpGameOverFadeLevel) {
                    GameScreen.fpGameFade = moveValue(GameScreen.fpGameFade, cfpGameOverFadeLevel, ((cfpGameOverFadeRate ^ dt) & 134217728) != 0 ? -((int) (((-cfpGameOverFadeRate) * dt) >> 16)) : (int) ((cfpGameOverFadeRate * dt) >> 16));
                }
                if (player.fpFadeAlpha > 0) {
                    player.fpFadeAlpha = moveValue(player.fpFadeAlpha, 0, ((32768 ^ dt) & 134217728) != 0 ? -((int) (((-32768) * dt) >> 16)) : (int) ((32768 * dt) >> 16));
                }
                switch (this.gameSubState) {
                    case 0:
                        if (this.fpGameStateTime > 65536) {
                            this.gameSubState = 1;
                            this.fpGameStateTime = 0;
                            boolean isHighScore = GameApp.hiscoreTable.isHiscore(0, this.playerScore);
                            GameApp.gameScreen.setGameOverText(this.playerScore, isHighScore);
                            return;
                        }
                        return;
                    case 1:
                        if (player.fpFadeAlpha == 0) {
                            GameApp.gameScreen.pushGameOverMenu();
                            this.gameSubState = 2;
                            return;
                        }
                        return;
                    default:
                        return;
                }
            default:
                return;
        }
    }

    public void updateAchsGameOver() {
        int[] iArr = achievements;
        iArr[0] = iArr[0] + 1;
        achievements[2] = this.playerScore;
        if (achievements[1] < this.playerScore) {
            achievements[1] = this.playerScore;
            FrontEnd.canUploadHiScore = true;
        }
        int totalScore = (achievements[3] * (achievements[0] - 1)) + this.playerScore;
        achievements[3] = totalScore / achievements[0];
        int[] iArr2 = achievements;
        iArr2[5] = iArr2[5] + (this.gameTime / CharacterSets.UCS2);
        achievements[4] = achievements[5] / achievements[0];
        if (achievements[6] < GameObj.playerNumBonusItemsCollected) {
            achievements[6] = GameObj.playerNumBonusItemsCollected;
        }
        int[] iArr3 = achievements;
        iArr3[7] = iArr3[7] + GameObj.playerTotalEaten;
        if (achievements[9] < this.playerBestStreakScore) {
            achievements[9] = this.playerBestStreakScore;
        }
        int sharkSize = GameObj.sharkTable[GameObj.sharkLevel][7];
        if (sharkSize > achievements[8]) {
            achievements[8] = sharkSize;
        }
    }

    public static String getAchString(int id) {
        switch (id) {
            case 4:
            case 5:
                return formatTimeSeconds(achievements[id]);
            case 6:
            case 7:
            default:
                return formatNumber(achievements[id]);
            case 8:
                int n = achievements[id];
                int cm = n % 100;
                int m = (n - cm) / 100;
                return "" + m + "." + GameApp.formatNumber(cm, 2, '0') + "m";
        }
    }

    public static String getRankingName(int score) {
        return score >= rankingScores[18] ? "Megalodon" : score >= rankingScores[17] ? "Great White" : score >= rankingScores[16] ? "Kemptron Shark" : score >= rankingScores[15] ? "Dragon Shark" : score >= rankingScores[14] ? "Tiger Shark" : score >= rankingScores[13] ? "Leopard Shark" : score >= rankingScores[12] ? "Great Hammerhead\nShark" : score >= rankingScores[11] ? "Bull Shark" : score >= rankingScores[10] ? "Lemon Shark" : score >= rankingScores[9] ? "Hammerhead Shark" : score >= rankingScores[8] ? "Velvet Belly Shark" : score >= rankingScores[7] ? "Fat Catshark" : score >= rankingScores[6] ? "Gulper" : score >= rankingScores[5] ? "Silky Shark" : score >= rankingScores[4] ? "Little Gulper" : score >= rankingScores[3] ? "Dwarf Catshark" : score >= rankingScores[2] ? "Pygmy Shark" : score >= rankingScores[1] ? "Dumb Shark" : "Blind Shark";
    }

    public static int getCurrentRankingScore() {
        return achievements[1];
    }

    public static String getCurrentRankingName() {
        return getRankingName(getCurrentRankingScore());
    }

    public static String formatNumber(int n) {
        if (n == 0) {
            return "0";
        }
        String s = "";
        while (n > 0) {
            int r = n % CharacterSets.UCS2;
            if (n >= 1000) {
                s = "," + GameApp.formatNumber(r, 3, '0') + s;
            } else {
                s = "" + r + s;
            }
            n = (n - r) / CharacterSets.UCS2;
        }
        return s;
    }

    public static String formatTimeSeconds(int n) {
        int secs = n % 60;
        int n2 = (n - secs) / 60;
        int mins = n2 % 60;
        return "" + ((n2 - mins) / 60) + ":" + GameApp.formatNumber(mins, 2, '0') + ":" + GameApp.formatNumber(secs, 2, '0');
    }

    public int getGameObjSaveID(GameObj obj) {
        if (obj == null) {
            return -1;
        }
        return obj.allocIndex;
    }

    public GameObj getGameObjFromSaveID(int id) {
        if (id == -1) {
            return null;
        }
        GameObj obj = this.gameObjSlots[id];
        return obj;
    }

    public void saveState(DataOutputStream outputStream) {
        try {
            outputStream.writeInt(this.gameTime);
            outputStream.writeInt(this.playerScore);
            outputStream.writeInt(this.playerKillChain);
            outputStream.writeInt(this.fpPlayerKillChainTimer);
            outputStream.writeInt(this.playerStreakStartScore);
            outputStream.writeInt(this.playerBestStreakScore);
            outputStream.writeInt(this.gameState);
            outputStream.writeInt(this.gameSubState);
            outputStream.writeInt(this.fpGameStateTime);
            outputStream.writeInt(this.fpCameraOffsetX);
            outputStream.writeInt(this.fpCameraOffsetY);
            outputStream.writeInt(this.fpCameraPosX);
            outputStream.writeInt(this.fpCameraPosY);
            outputStream.writeInt(this.fpFilteredMaxRot);
            outputStream.writeInt(this.fpCameraStartPosBlend);
            outputStream.writeInt(this.fpLastDesiredSpeed);
            GameApp.outputStreamWriteIntArray(outputStream, this.rectVisible);
            GameApp.outputStreamWriteIntArray(outputStream, this.rectCullSpawner);
            GameApp.outputStreamWriteIntArray(outputStream, this.rectActivateSpawner);
            for (int i = 0; i < 6; i++) {
                GameApp.outputStreamWriteIntArray(outputStream, this.multiKillTimes[i]);
            }
            GameApp.outputStreamWriteIntArray(outputStream, this.multiKillNextIndex);
            outputStream.writeInt(this.scoreMultiplier);
            GameApp.outputStreamWriteIntArray(outputStream, this.npcNumActive);
            GameApp.outputStreamWriteIntArray(outputStream, this.npcNumKilled);
            spawner.saveState(outputStream);
            refreshGameObjList();
            GameObj.saveStaticVars(outputStream);
            outputStream.writeInt(this.numGameObj);
            for (int i2 = 0; i2 < this.numGameObj; i2++) {
                this.gameObjList[i2].allocIndex = i2;
            }
            for (int i3 = 0; i3 < this.numGameObj; i3++) {
                this.gameObjList[i3].saveState(outputStream);
            }
        } catch (Exception e) {
        }
    }

    public void loadState(DataInputStream inputStream) {
        try {
            this.gameTime = inputStream.readInt();
            this.playerScore = inputStream.readInt();
            this.playerKillChain = inputStream.readInt();
            this.fpPlayerKillChainTimer = inputStream.readInt();
            this.playerStreakStartScore = inputStream.readInt();
            this.playerBestStreakScore = inputStream.readInt();
            this.gameState = inputStream.readInt();
            this.gameSubState = inputStream.readInt();
            this.fpGameStateTime = inputStream.readInt();
            this.fpCameraOffsetX = inputStream.readInt();
            this.fpCameraOffsetY = inputStream.readInt();
            this.fpCameraPosX = inputStream.readInt();
            this.fpCameraPosY = inputStream.readInt();
            this.fpFilteredMaxRot = inputStream.readInt();
            this.fpCameraStartPosBlend = inputStream.readInt();
            this.fpLastDesiredSpeed = inputStream.readInt();
            GameApp.inputStreamReadIntArray(inputStream, this.rectVisible);
            GameApp.inputStreamReadIntArray(inputStream, this.rectCullSpawner);
            GameApp.inputStreamReadIntArray(inputStream, this.rectActivateSpawner);
            for (int i = 0; i < 6; i++) {
                GameApp.inputStreamReadIntArray(inputStream, this.multiKillTimes[i]);
            }
            GameApp.inputStreamReadIntArray(inputStream, this.multiKillNextIndex);
            this.scoreMultiplier = inputStream.readInt();
            GameApp.inputStreamReadIntArray(inputStream, this.npcNumActive);
            GameApp.inputStreamReadIntArray(inputStream, this.npcNumKilled);
            spawner.loadState(inputStream);
            GameObj.loadStaticVars(inputStream);
            int numObj = inputStream.readInt() - 1;
            for (int i2 = 0; i2 < numObj; i2++) {
                allocateGameObj();
            }
            for (int i3 = 0; i3 < this.numGameObj; i3++) {
                GameObj obj = this.gameObjList[i3];
                obj.loadState(inputStream);
            }
            refreshGameObjList();
            GameScreen.fpFullScreenFade = 0;
            updateCamera();
            GameApp.gameScreen.setIntroText("", 0, false);
        } catch (Exception e) {
        }
    }
}
