package com.slg.j2me.game;

import java.io.DataInputStream;
import java.io.DataOutputStream;
import java.io.IOException;
import java.io.InputStream;
import java.io.OutputStream;
import java.net.HttpURLConnection;
import java.net.URL;
import java.util.Vector;
/* loaded from: classes.dex */
class HiscoreTable {
    public static final int cMaxScores = 8;
    public static boolean modified = false;
    public static int numTables = 4;
    private Vector[] levelScores;

    private static void SORT_segmentedInsertionSort(Vector v, int distance, int segment) {
        int i = segment + distance;
        while (i < v.size()) {
            int j = i;
            while (j >= distance) {
                Score a2 = (Score) v.elementAt(j);
                Score b = (Score) v.elementAt(j - distance);
                if (a2.compareTo(b) <= 0) {
                    SORT_swap(v, j, j - distance);
                    j -= distance;
                }
            }
            i += distance;
        }
    }

    public static void SORT_shellSort(Vector v) {
        for (int distance = v.size() / 2; distance > 0; distance /= 2) {
            for (int segment = 0; segment < distance; segment++) {
                SORT_segmentedInsertionSort(v, distance, segment);
            }
        }
    }

    private static void SORT_swap(Vector v, int i, int j) {
        Object temp = v.elementAt(i);
        v.setElementAt(v.elementAt(j), i);
        v.setElementAt(temp, j);
    }

    public HiscoreTable(int _numTables) {
        this.levelScores = null;
        numTables = _numTables;
        this.levelScores = new Vector[numTables];
        for (int t = 0; t < numTables; t++) {
            this.levelScores[t] = new Vector();
            for (int i = 0; i < 8; i++) {
                Score score = new Score(0, 0);
                this.levelScores[t].addElement(score);
            }
        }
        modified = true;
    }

    public void makeDefaultTable(int tables, String[] defaultNames, int[][] defaultScores, int[][] defaultTimes) {
        for (int t = 0; t < tables; t++) {
            this.levelScores[t].removeAllElements();
            for (int i = 0; i < defaultNames.length; i++) {
                int points = defaultScores[t][i];
                Score score = new Score(points, defaultTimes[t][i]);
                score.name = defaultNames[i];
                this.levelScores[t].addElement(score);
            }
        }
        modified = true;
    }

    public int getNumScores(int table) {
        return this.levelScores[table].size();
    }

    public int getScore(int table, int position) {
        return ((Score) this.levelScores[table].elementAt(position)).points;
    }

    public void setScore(int table, int position, int score) {
        ((Score) this.levelScores[table].elementAt(position)).points = score;
        modified = true;
    }

    public int getTime(int table, int position) {
        return ((Score) this.levelScores[table].elementAt(position)).time;
    }

    public void setTime(int table, int position, int time) {
        ((Score) this.levelScores[table].elementAt(position)).time = time;
        modified = true;
    }

    public String getName(int table, int position) {
        return ((Score) this.levelScores[table].elementAt(position)).name;
    }

    public void setName(int table, int position, String name) {
        ((Score) this.levelScores[table].elementAt(position)).name = name;
        modified = true;
    }

    public boolean isHiscore(int table, int score) {
        int last_in_table = getScore(table, getNumScores(table) - 1);
        return score > last_in_table;
    }

    public int getHiscorePlace(int table, int score) {
        for (int i = 0; i < getNumScores(table); i++) {
            if (score > getScore(table, i)) {
                return i;
            }
        }
        return -1;
    }

    public int getLowestScore(int table) {
        int score = 999999999;
        for (int i = 0; i < getNumScores(table); i++) {
            if (score > getScore(table, i)) {
                score = getScore(table, i);
            }
        }
        return score;
    }

    public int getLowestPlace(int table) {
        int score = 999999999;
        int place = -1;
        for (int i = 0; i < getNumScores(table); i++) {
            if (score > getScore(table, i)) {
                place = i;
                score = getScore(table, i);
            }
        }
        return place;
    }

    public String createHiscoreURL(int points, String name) {
        return "http://staging.geocade.com/scores/submitScore";
    }

    public String createHiscoreContent(int points, String name) {
        StringBuffer str = new StringBuffer("cid=&gid=37130&lat=0&lng=0&msg=");
        str.append(name);
        str.append('&');
        str.append("token=37130dks93shqiawkodnvli39&total=");
        str.append(points + "&uid=shwef23plk71547a1a2c5ade7549c9decc209964b4ec");
        return str.toString();
    }

    public void addHiscore(int table, int points, int time, String name) {
        Score score = (Score) this.levelScores[table].elementAt(getNumScores(table) - 1);
        score.points = points;
        score.name = name;
        score.time = time;
        SORT_shellSort(this.levelScores[table]);
        modified = true;
    }

    private InputStream doPost(String urlString, String content) throws IOException {
        URL url = new URL(urlString);
        HttpURLConnection con = (HttpURLConnection) url.openConnection();
        con.setRequestMethod("POST");
        con.setRequestProperty("Content-Length", "" + Integer.toString(content.getBytes().length));
        con.setDoOutput(true);
        con.setDoInput(true);
        con.connect();
        OutputStream out = con.getOutputStream();
        byte[] buff = content.getBytes("UTF8");
        out.write(buff);
        out.flush();
        out.close();
        return con.getInputStream();
    }

    public void saveHiscores(DataOutputStream dataStream) {
        try {
            dataStream.writeInt(numTables);
            for (int t = 0; t < numTables; t++) {
                int num = getNumScores(t);
                dataStream.writeInt(num);
                for (int i = 0; i < num; i++) {
                    Score score = (Score) this.levelScores[t].elementAt(i);
                    dataStream.writeInt(score.points);
                    dataStream.writeInt(score.time);
                    if (score.name != null) {
                        dataStream.writeUTF(score.name);
                    } else {
                        dataStream.writeShort(0);
                    }
                }
            }
        } catch (Exception e) {
            e.printStackTrace();
        }
    }

    /* JADX INFO: Access modifiers changed from: protected */
    public void loadHiscores(DataInputStream inputStream) throws IOException {
        numTables = inputStream.readInt();
        for (int t = 0; t < numTables; t++) {
            int num = inputStream.readInt();
            this.levelScores[t].removeAllElements();
            for (int i = 0; i < num; i++) {
                int pts = inputStream.readInt();
                int time = inputStream.readInt();
                Score score = new Score(pts, time);
                score.name = inputStream.readUTF();
                this.levelScores[t].addElement(score);
            }
        }
        modified = false;
    }
}
