package com.slg.j2me.lib.gfx;

import com.slg.j2me.lib.sys.Application;
import java.io.DataInputStream;
import java.io.IOException;
import java.io.InputStream;
import java.util.Enumeration;
import java.util.Hashtable;
import java.util.Vector;
import javax.microedition.lcdui.glGraphics;
import javax.microedition.lcdui.j2meImage;
/* loaded from: classes.dex */
public class ImageSet {
    public static final byte cFlagContainsOffsets = 2;
    public static final byte cFlagContainsSlicedImages = 4;
    public static final byte cFlagIsAFont = 1;
    public static final byte cRecordFlagSliceIndex = 4;
    public static final byte cRecordFlagXCropped = 1;
    public static final byte cRecordFlagYCropped = 2;
    private static String imagesetname;
    public static String sCharacters;
    public byte flags;
    private Hashtable hashImageSeqCache = new Hashtable();
    private String[] source_is_anim = null;
    private static j2meImage imagesetimage = null;
    private static Vector vecImagesets = new Vector();
    public static int totalVideoMemoryUsed = 0;

    public ImageSet(String fileName, boolean loadImages) {
        sCharacters = "";
        InputStream inputstream = Application.openResourceAsStream(fileName + ".idx");
        if (inputstream != null) {
            loadImageSetBinary(fileName, inputstream, loadImages);
        }
        vecImagesets.addElement(this);
        Application.gc();
    }

    private void loadImageSetBinary(String fileName, InputStream inputstream, boolean loadImages) {
        String texName;
        int w;
        int h;
        DataInputStream reader = new DataInputStream(inputstream);
        Application.printMemoryStatus();
        int dot = fileName.indexOf(".");
        String nameImageSet = fileName.substring(1, dot);
        try {
            reader.readShort();
            this.flags = reader.readByte();
            int files = reader.readShort();
            int entries = reader.readShort();
            int entry = 0;
            while (entry < entries) {
                int frames = reader.readShort();
                String labelName = reader.readUTF();
                ImageSequence imageSequence = (ImageSequence) this.hashImageSeqCache.get(labelName);
                ImageSequence imageSeq = new ImageSequence();
                this.hashImageSeqCache.put(labelName, imageSeq);
                imageSeq.setup(this.flags, frames, files);
                int i = 0;
                entry = entry;
                while (i < frames) {
                    byte sequenceFlags = reader.readByte();
                    int frameIndex = reader.readByte();
                    short charCode = -1;
                    if (frameIndex > 9) {
                        texName = nameImageSet + "_" + frameIndex + ".png";
                    } else {
                        texName = nameImageSet + "_0" + frameIndex + ".png";
                    }
                    imageSeq.addImageIfNew(texName);
                    if (imageSeq.imageIndex != null) {
                        imageSeq.imageIndex[i] = (byte) imageSeq.getImageIndex(texName);
                    }
                    int x = 0;
                    int y = 0;
                    if ((sequenceFlags & 4) != 0) {
                        w = reader.readByte();
                        h = reader.readByte();
                        for (int j = 0; j < 3; j++) {
                            reader.readShort();
                        }
                    } else {
                        x = reader.readShort();
                        y = reader.readShort();
                        w = reader.readShort();
                        h = reader.readShort();
                    }
                    int offsetx = 0;
                    int offsety = 0;
                    int offsetw = 0;
                    int offseth = 0;
                    if ((sequenceFlags & 1) != 0) {
                        offsetx = reader.readShort();
                        offsetw = reader.readShort();
                    }
                    if ((sequenceFlags & 2) != 0) {
                        offsety = reader.readShort();
                        offseth = reader.readShort();
                    }
                    if ((this.flags & 1) != 0) {
                        charCode = reader.readShort();
                    }
                    imageSeq.setRect(i, x, y, w, h, offsetx, offsety, offsetw, offseth);
                    if (loadImages) {
                        loadImage(imageSeq, i);
                    }
                    if ((this.flags & 1) != 0) {
                        sCharacters += ((char) charCode);
                    }
                    i++;
                    entry++;
                }
            }
            if ((this.flags & 4) != 0) {
                int entries2 = reader.readShort();
                int entry2 = 0;
                while (entry2 < entries2) {
                    int frames2 = reader.readShort();
                    String labelName2 = reader.readUTF();
                    ImageSequence imageSequence2 = (ImageSequence) this.hashImageSeqCache.get(labelName2);
                    ImageSequence imageSeq2 = new ImageSequence();
                    this.hashImageSeqCache.put(labelName2, imageSeq2);
                    imageSeq2.setup((byte) 0, frames2, 1);
                    int i2 = 0;
                    entry2 = entry2;
                    while (i2 < frames2) {
                        int x2 = reader.readShort();
                        int y2 = reader.readShort();
                        int w2 = reader.readShort();
                        int h2 = reader.readShort();
                        imageSeq2.setRect(i2, x2, y2, w2, h2, 0, 0, 0, 0);
                        i2++;
                        entry2++;
                    }
                }
            }
            reader.close();
        } catch (IOException e) {
        }
        Application.printMemoryStatus();
    }

    public void destruct() {
        vecImagesets.removeElement(this);
    }

    public int getNumFrames(String sequenceName) {
        ImageSequence imageSeq = (ImageSequence) this.hashImageSeqCache.get(sequenceName);
        if (imageSeq == null) {
            return -1;
        }
        return imageSeq.numFrames;
    }

    public static j2meImage loadImage(String filename) {
        j2meImage image = findImageGlobal(filename);
        if (image != null) {
            return image;
        }
        Application.gc();
        Application.printMemoryStatus();
        j2meImage image2 = j2meImage.createImage(filename);
        Application.printMemoryStatus();
        return image2;
    }

    public ImageSequence getImageSequence(String sequenceName) {
        return (ImageSequence) this.hashImageSeqCache.get(sequenceName);
    }

    public static j2meImage makeImage(String imageset, ClipRect clip) {
        j2meImage imagesetImage = getImageSet(imageset);
        if (imagesetImage != null) {
            int width = (clip.x0 + clip.w < imagesetImage.getWidth() ? clip.x0 + clip.w : imagesetImage.getWidth()) - clip.x0;
            int height = (clip.y0 + clip.h < imagesetImage.getHeight() ? clip.y0 + clip.h : imagesetImage.getHeight()) - clip.y0;
            j2meImage frame = j2meImage.createImage(imagesetImage, clip.x0, clip.y0, width, height, 0);
            return frame;
        }
        return null;
    }

    private String getSequenceName(String line) {
        try {
            int start = line.indexOf(47);
            int end = line.indexOf(95, start);
            String ret = new String(line.substring(start + 1, end));
            return ret;
        } catch (Exception ex) {
            ex.printStackTrace();
            return null;
        }
    }

    private String getImageSetName(String line) {
        int end = line.indexOf(47, 0);
        return new String(line.substring(0, end));
    }

    public static j2meImage getImageSet(String name) {
        if (imagesetimage == null || imagesetname.compareTo(name) != 0) {
            imagesetimage = null;
            imagesetimage = loadImage("/" + name);
            imagesetname = name;
        }
        return imagesetimage;
    }

    public static void loadImage(ImageSequence imageSeq, int i) {
        int index = imageSeq.imageIndex != null ? imageSeq.imageIndex[i] : 0;
        if (imageSeq.imageFrame[index] == null) {
            String filename = (String) imageSeq.vecImageFilenames.elementAt(index);
            imageSeq.imageFrame[index] = getImageSet(filename);
        }
    }

    public void unloadImages() {
        Enumeration seqs = this.hashImageSeqCache.elements();
        while (seqs.hasMoreElements()) {
            ImageSequence seq = (ImageSequence) seqs.nextElement();
            seq.unload();
        }
    }

    public void reloadImages() {
        Enumeration seqs = this.hashImageSeqCache.elements();
        while (seqs.hasMoreElements()) {
            ImageSequence seq = (ImageSequence) seqs.nextElement();
            seq.reload();
        }
    }

    public static j2meImage findImageGlobal(String filename) {
        for (int i = 0; i < vecImagesets.size(); i++) {
            j2meImage image = ((ImageSet) vecImagesets.elementAt(i)).findImage(filename);
            if (image != null) {
                return image;
            }
        }
        return null;
    }

    public j2meImage findImage(String filename) {
        Enumeration seqs = this.hashImageSeqCache.elements();
        while (seqs.hasMoreElements()) {
            ImageSequence seq = (ImageSequence) seqs.nextElement();
            for (int i = 0; i < seq.vecImageFilenames.size(); i++) {
                String str = (String) seq.vecImageFilenames.elementAt(i);
                if (seq.imageFrame[i] != null && filename.equals("/" + str)) {
                    return seq.imageFrame[i];
                }
            }
        }
        return null;
    }

    public void printResidentImages() {
        Enumeration seqs = this.hashImageSeqCache.elements();
        Hashtable hashNames = new Hashtable();
        while (seqs.hasMoreElements()) {
            ImageSequence seq = (ImageSequence) seqs.nextElement();
            for (int i = 0; i < seq.vecImageFilenames.size(); i++) {
                if (seq.imageFrame[i] != null) {
                    hashNames.put(seq.imageFrame[i], seq.vecImageFilenames.elementAt(i));
                }
            }
        }
        Enumeration seqs2 = hashNames.elements();
        Enumeration seqskey = hashNames.keys();
        while (seqs2.hasMoreElements()) {
            String str = (String) seqs2.nextElement();
            j2meImage image = (j2meImage) seqskey.nextElement();
            int bytes_used = image.getWidth() * 4 * image.getHeight();
            totalVideoMemoryUsed += bytes_used;
            int i2 = bytes_used / glGraphics.cMaxSprites;
        }
    }

    public static void printResidentImagesGlobal() {
        totalVideoMemoryUsed = 0;
        for (int i = 0; i < vecImagesets.size(); i++) {
            ImageSet is = (ImageSet) vecImagesets.elementAt(i);
            is.printResidentImages();
        }
        int i2 = totalVideoMemoryUsed / glGraphics.cMaxSprites;
    }
}
