package com.slg.j2me.lib.gui.layout;

import com.slg.j2me.lib.gfx.ClipRect;
import com.slg.j2me.lib.gui.control.GuiContainer;
import javax.microedition.lcdui.Graphics;
/* loaded from: classes.dex */
public class CellLayout extends ScreenLayout {
    public GuiContainer[][] cellContainers;
    public int[][] cellLayout;
    public int[][] cellProportions;
    public int cellRows;
    ClipRect newRect = new ClipRect(0, 0, 0, 0);
    ClipRect oldRect;
    public int[] rowProportions;

    public CellLayout(int rows) {
        init(rows);
    }

    private void init(int rows) {
        this.cellRows = rows;
        this.cellContainers = new GuiContainer[rows];
        this.cellProportions = new int[rows];
        this.cellLayout = new int[rows];
        this.rowProportions = new int[rows];
    }

    public void setRow(int row, int cells, int proportion) {
        this.rowProportions[row] = proportion;
        this.cellProportions[row] = new int[cells];
        for (int i = 0; i < cells; i++) {
            this.cellProportions[row][i] = 1;
        }
        this.cellLayout[row] = new int[cells];
        this.cellContainers[row] = new GuiContainer[cells];
    }

    public void setRowFlags(int row, int proportion) {
        this.rowProportions[row] = proportion;
    }

    public void setCell(int row, int cell, GuiContainer container, int proportion, int layout) {
        this.cellProportions[row][cell] = proportion;
        this.cellLayout[row][cell] = layout;
        this.cellContainers[row][cell] = container;
        if (container != null) {
            container.parentLayout = this;
        }
    }

    public void setCellFlags(int row, int cell, int proportion, int layout) {
        this.cellProportions[row][cell] = proportion;
        this.cellLayout[row][cell] = layout;
    }

    @Override // com.slg.j2me.lib.gui.layout.ScreenLayout
    public void open() {
        super.open();
        layout();
    }

    @Override // com.slg.j2me.lib.gui.layout.ScreenLayout
    public void close() {
        for (int row = 0; row < this.cellRows; row++) {
            if (this.cellContainers[row] != null) {
                for (int i = 0; i < this.cellContainers[row].length; i++) {
                    GuiContainer container = this.cellContainers[row][i];
                    if (container instanceof ScreenLayout) {
                        ScreenLayout layoutcontainer = (ScreenLayout) container;
                        layoutcontainer.close();
                    }
                }
            }
        }
        super.close();
    }

    @Override // com.slg.j2me.lib.gui.layout.ScreenLayout
    public void layout() {
        super.layout();
        int totalproportion = 0;
        for (int i = 0; i < this.cellRows; i++) {
            try {
                if (this.rowProportions[i] >= 0) {
                    totalproportion += this.rowProportions[i];
                }
            } catch (Exception e) {
                return;
            }
        }
        int[] row_y0 = new int[this.cellRows];
        int[] row_h = new int[this.cellRows];
        int sum = 0;
        int fixed_space = 0;
        int variable_space = this.clipRect.h;
        for (int row = 0; row < this.cellRows; row++) {
            int max_h = 0;
            if (this.cellContainers[row] != null) {
                for (int i2 = 0; i2 < this.cellContainers[row].length; i2++) {
                    if (this.cellContainers[row][i2] != null) {
                        try {
                            this.cellContainers[row][i2].initialise();
                            if (max_h <= this.cellContainers[row][i2].clipRect.h) {
                                max_h = this.cellContainers[row][i2].clipRect.h;
                            }
                        } catch (Exception e2) {
                        }
                    }
                }
            }
            if (this.rowProportions[row] < 0) {
                fixed_space += max_h;
            }
        }
        int variable_space2 = variable_space - fixed_space;
        if (variable_space2 == 0 || totalproportion == 0) {
            variable_space2 = 0;
            this.clipRect.h = (short) fixed_space;
            totalproportion = 1;
        }
        int fixed_space2 = 0;
        for (int row2 = 0; row2 < this.cellRows; row2++) {
            row_y0[row2] = ((sum * variable_space2) / totalproportion) + fixed_space2;
            if (this.rowProportions[row2] >= 0) {
                sum += this.rowProportions[row2];
            } else {
                int max_h2 = 0;
                if (this.cellContainers[row2] != null) {
                    for (int i3 = 0; i3 < this.cellContainers[row2].length; i3++) {
                        if (this.cellContainers[row2][i3] != null && max_h2 <= this.cellContainers[row2][i3].clipRect.h) {
                            max_h2 = this.cellContainers[row2][i3].clipRect.h;
                        }
                    }
                }
                fixed_space2 += max_h2;
            }
            row_h[row2] = (((sum * variable_space2) / totalproportion) + fixed_space2) - row_y0[row2];
        }
        int max_width = 0;
        for (int row3 = 0; row3 < this.cellRows; row3++) {
            if (this.cellProportions[row3] != null) {
                int totalproportion2 = 0;
                int fixed_space3 = 0;
                int sum2 = 0;
                int variable_space3 = this.clipRect.w;
                for (int i4 = 0; i4 < this.cellProportions[row3].length; i4++) {
                    if (this.cellProportions[row3][i4] >= 0) {
                        totalproportion2 += this.cellProportions[row3][i4];
                    } else {
                        fixed_space3 += this.cellContainers[row3][i4].clipRect.w;
                    }
                }
                int variable_space4 = variable_space3 - fixed_space3;
                if (variable_space4 == 0 || totalproportion2 == 0) {
                    variable_space4 = 0;
                    if (max_width <= fixed_space3) {
                        max_width = fixed_space3;
                    }
                    totalproportion2 = 1;
                } else {
                    max_width = this.clipRect.w;
                }
                int fixed_space4 = 0;
                for (int i5 = 0; i5 < this.cellProportions[row3].length; i5++) {
                    try {
                        GuiContainer container = this.cellContainers[row3][i5];
                        if (container != null) {
                            int x0 = ((sum2 * variable_space4) / totalproportion2) + fixed_space4;
                            int y0 = row_y0[row3];
                            if (this.cellProportions[row3][i5] >= 0) {
                                sum2 += this.cellProportions[row3][i5];
                            } else {
                                fixed_space4 += container.clipRect.w;
                            }
                            int w = (((sum2 * variable_space4) / totalproportion2) + fixed_space4) - x0;
                            int h = row_h[row3];
                            if ((this.cellLayout[row3][i5] & 2) != 0) {
                                if (h - container.clipRect.h > 0) {
                                    container.clipRect.y0 = (short) (((h - container.clipRect.h) / 2) + y0);
                                } else {
                                    container.clipRect.y0 = (short) y0;
                                    container.clipRect.h = (short) h;
                                }
                            } else {
                                container.clipRect.y0 = (short) y0;
                                container.clipRect.h = (short) h;
                            }
                            if ((this.cellLayout[row3][i5] & 1) != 0) {
                                if (w - container.clipRect.w > 0) {
                                    container.clipRect.x0 = (short) (((w - container.clipRect.w) / 2) + x0);
                                } else {
                                    container.clipRect.x0 = (short) x0;
                                }
                            } else {
                                container.clipRect.x0 = (short) x0;
                                container.clipRect.w = (short) w;
                            }
                            if (container instanceof ScreenLayout) {
                                ScreenLayout layoutcontainer = (ScreenLayout) container;
                                layoutcontainer.layout();
                            }
                        } else {
                            sum2 += this.cellProportions[row3][i5];
                        }
                    } catch (Exception e3) {
                    }
                }
            }
        }
        if (max_width != 0) {
            this.clipRect.w = (short) max_width;
        }
    }

    @Override // com.slg.j2me.lib.gui.layout.ScreenLayout, com.slg.j2me.lib.gui.control.GuiContainer
    public void paint(Graphics g) {
        for (int row = 0; row < this.cellRows; row++) {
            if (this.cellContainers[row] != null && this.rowProportions[row] != 0) {
                for (int i = 0; i < this.cellContainers[row].length; i++) {
                    GuiContainer container = this.cellContainers[row][i];
                    if (container != null) {
                        try {
                            this.oldRect = container.clipRect;
                            this.newRect.x0 = (short) (this.clipRect.x0 + container.clipRect.x0);
                            this.newRect.y0 = (short) (this.clipRect.y0 + container.clipRect.y0);
                            this.newRect.w = (short) ((this.newRect.x0 + container.clipRect.w < this.clipRect.x0 + this.clipRect.w ? this.newRect.x0 + container.clipRect.w : this.clipRect.x0 + this.clipRect.w) - this.newRect.x0);
                            this.newRect.h = (short) ((this.newRect.y0 + container.clipRect.h < this.clipRect.y0 + this.clipRect.h ? this.newRect.y0 + container.clipRect.h : this.clipRect.y0 + this.clipRect.h) - this.newRect.y0);
                            if (this.newRect.w > 0 && this.newRect.h > 0) {
                                container.clipRect = this.newRect;
                                container.paint(g);
                            }
                            container.clipRect = this.oldRect;
                        } catch (Exception e) {
                            e.printStackTrace();
                        }
                    }
                }
            }
        }
        super.paint(g);
    }

    @Override // com.slg.j2me.lib.gui.layout.ScreenLayout, com.slg.j2me.lib.gui.control.GuiContainer
    public void process() {
        for (int row = 0; row < this.cellRows; row++) {
            if (this.cellContainers[row] != null) {
                for (int i = 0; i < this.cellContainers[row].length; i++) {
                    GuiContainer container = this.cellContainers[row][i];
                    if (container != null) {
                        container.clipRect.translate(this.clipRect);
                        container.process();
                        container.clipRect.untranslate(this.clipRect);
                    }
                }
            }
        }
        super.process();
    }
}
