package com.slg.j2me.lib.gui.layout;

import com.slg.j2me.lib.gfx.BaseScreen;
import com.slg.j2me.lib.gfx.ClipRect;
import com.slg.j2me.lib.gfx.ImageSet;
import com.slg.j2me.lib.gui.Transition;
import com.slg.j2me.lib.gui.control.ControlHandler;
import com.slg.j2me.lib.gui.control.GuiContainer;
import com.slg.j2me.lib.gui.control.GuiControl;
import com.slg.j2me.lib.sys.Application;
import java.util.Vector;
import javax.microedition.lcdui.Graphics;
import javax.microedition.lcdui.j2meImage;
/* loaded from: classes.dex */
public abstract class ScreenStack extends BaseScreen implements ControlHandler {
    public static ScreenLayout currentContainer = null;
    public static ScreenLayout currentDialog = null;
    public static final int eScreenBack = 3;
    public static final int eScreenForward = 2;
    public static final int eScreenOpen = 1;
    public static final int eScreenOpening = 0;
    public static final int eventTransitionFinished = 1;
    public static final int eventWipeFinished = 2;
    public static ScreenStack instance;
    public static ScreenLayout nextScreen;
    public j2meImage backgroundImage;
    public int colBackground;
    private String lastImage;
    public int menuButtons;
    private boolean popPreviousScreenOnScreenOpen;
    protected Vector screenStack;
    public static int screenState = 0;
    private static Vector taskList = new Vector();
    private static Vector eventList = new Vector();
    public static GuiControl ctrlLeftSoftKey = new GuiControl(true);
    public static GuiControl ctrlRightSoftKey = new GuiControl(true);
    public static int wipeDirection = 0;
    public static int lastWipeDirection = 0;
    public static j2meImage imgWipeScreen = null;
    public static GuiControl wipeContainer = new GuiControl(false);
    public static ClipRect wipeClip = new ClipRect(0, 0, displayWidth, displayHeight);
    public static int wipeOffsetX = 0;
    public static int wipeOffsetY = 0;
    public static boolean wipeInProgress = false;

    public abstract void controlExecuted(ScreenLayout screenLayout, GuiControl guiControl);

    public abstract void onScreenOpen(ScreenLayout screenLayout);

    public abstract void open();

    public ScreenStack() {
        super(false);
        this.backgroundImage = null;
        this.colBackground = -1;
        this.menuButtons = 0;
        this.popPreviousScreenOnScreenOpen = false;
        this.lastImage = "";
        instance = this;
        this.screenStack = new Vector();
        imgWipeScreen = j2meImage.createImage(displayWidth, displayHeight);
    }

    public void setBackgroundColour(int colour) {
        this.colBackground = colour;
    }

    public void loadImage(String filename) {
        if (this.backgroundImage == null || !filename.equals(this.lastImage)) {
            this.lastImage = filename;
            this.backgroundImage = ImageSet.loadImage(filename);
        }
    }

    public void open(ScreenLayout screenToOpen) {
        this.screenStack.setSize(0);
        clearTasks();
        clearEvents();
        pushScreen(screenToOpen, false);
        doScreenState(0);
    }

    public void popPreviousScreen() {
        if (this.screenStack.size() > 1) {
            this.screenStack.removeElementAt(this.screenStack.size() - 2);
        }
    }

    @Override // com.slg.j2me.lib.gui.control.ControlHandler
    public void pushScreen(ScreenLayout container, boolean transition) {
        outputScreenStack();
        nextScreen = container;
        if (transition) {
            doScreenState(2);
        } else {
            doScreenState(1);
            pushScreenInternal();
        }
        outputScreenStack();
    }

    public void popScreen(boolean transition) {
        if (transition) {
            doScreenState(3);
            return;
        }
        doScreenState(1);
        popScreenInternal();
    }

    private boolean popScreenInternal() {
        resetKeys();
        if (currentContainer != null) {
            currentContainer.close();
            this.screenStack.removeElementAt(this.screenStack.size() - 1);
            if (this.screenStack.size() > 0) {
                currentContainer = (ScreenLayout) this.screenStack.elementAt(this.screenStack.size() - 1);
                onScreenOpen(currentContainer);
                currentContainer.open();
            } else {
                currentContainer = null;
            }
        }
        if (currentContainer == null) {
            open();
        }
        return currentContainer != null;
    }

    public ScreenLayout getPreviousScreen() {
        if (this.screenStack.size() > 1) {
            return (ScreenLayout) this.screenStack.elementAt(this.screenStack.size() - 2);
        }
        return null;
    }

    private void pushScreenInternal() {
        if (nextScreen != null) {
            if (currentContainer != null) {
                currentContainer.close();
            }
            currentContainer = nextScreen;
            this.screenStack.addElement(nextScreen);
            if (currentContainer.controlHandler == null) {
                currentContainer.controlHandler = this;
            }
            this.menuButtons = 0;
            nextScreen = null;
            try {
                onScreenOpen(currentContainer);
            } catch (Exception e) {
                e.printStackTrace();
            }
            resetKeys();
            currentContainer.open();
            if (this.popPreviousScreenOnScreenOpen) {
                popPreviousScreen();
                this.popPreviousScreenOnScreenOpen = false;
            }
        }
    }

    public void outputScreenStack() {
    }

    public void pushDialog(ScreenLayout dialog) {
        currentDialog = dialog;
        if (currentDialog.controlHandler == null) {
            currentDialog.controlHandler = this;
        }
        currentDialog.open();
    }

    public void popDialog() {
        if (currentDialog != null) {
            currentDialog.close();
            currentDialog = null;
        }
    }

    public void handleEvent(int event) {
        switch (event) {
            case 1:
                switch (screenState) {
                    case 0:
                        doScreenState(1);
                        return;
                    case 1:
                    default:
                        return;
                    case 2:
                        if (wipeDirection != 0) {
                            lastWipeDirection = wipeDirection;
                            startWipe();
                            instance.pushScreenInternal();
                            return;
                        }
                        lastWipeDirection = 0;
                        instance.pushScreenInternal();
                        doScreenState(0);
                        return;
                    case 3:
                        if (lastWipeDirection != 0) {
                            if ((lastWipeDirection & 1) != 0) {
                                wipeDirection = 2;
                            }
                            if ((lastWipeDirection & 4) != 0) {
                                wipeDirection = 8;
                            }
                            startWipe();
                            instance.popScreenInternal();
                            return;
                        }
                        instance.popScreenInternal();
                        doScreenState(0);
                        return;
                }
            case 2:
                wipeDirection = 0;
                wipeInProgress = false;
                doScreenState(0);
                return;
            default:
                return;
        }
    }

    public void startWipe() {
        Graphics g = imgWipeScreen.getGraphics();
        paintInternal(g);
        wipeContainer.clipRect.x0 = (short) 0;
        wipeContainer.clipRect.y0 = (short) 0;
        doTransition(wipeContainer, wipeDirection, 0, 500);
        addEvent(2, 500);
        if ((wipeDirection & 12) != 0) {
            wipeOffsetX = 0;
            if ((wipeDirection & 4) != 0) {
                wipeOffsetY = wipeClip.h;
            } else {
                wipeOffsetY = -wipeClip.h;
            }
        } else {
            wipeOffsetY = 0;
            if ((wipeDirection & 1) != 0) {
                wipeOffsetX = wipeClip.w;
            } else {
                wipeOffsetX = -wipeClip.w;
            }
        }
        wipeInProgress = true;
    }

    @Override // com.slg.j2me.lib.gfx.BaseScreen
    public void paintInternal(Graphics g) {
        if (currentContainer == null) {
            g.setColor(this.colBackground);
            g.fillRect(0, 0, BaseScreen.displayWidth, BaseScreen.displayHeight);
        }
        if (currentContainer != null) {
            currentContainer.paint(g);
        } else if (this.backgroundImage != null) {
            g.drawImage(this.backgroundImage, (displayWidth - this.backgroundImage.getWidth()) / 2, (displayHeight - this.backgroundImage.getHeight()) / 2, 8 | 5);
        }
        if (currentDialog != null) {
            currentDialog.paint(g);
        }
    }

    @Override // com.slg.j2me.lib.gfx.BaseScreen
    public void process() {
        super.process();
        processEvents();
        processTasks();
    }

    public static final void doTransition(GuiContainer control, int trans_type, int delay, int time) {
        int dx = 0;
        if ((trans_type & 1) != 0) {
            dx = -(control.clipRect.x0 + control.clipRect.w + 96);
        }
        if ((trans_type & 2) != 0) {
            dx = (BaseScreen.displayWidth - control.clipRect.x0) + 96;
        }
        int dy = (trans_type & 4) != 0 ? -(control.clipRect.y0 + control.clipRect.h + 96) : 0;
        if ((trans_type & 8) != 0) {
            dy = (BaseScreen.displayHeight - control.clipRect.y0) + 96;
        }
        if ((trans_type & 16) != 0) {
            ClipRect clipRect = control.clipRect;
            clipRect.x0 = (short) (clipRect.x0 + dx);
            ClipRect clipRect2 = control.clipRect;
            clipRect2.y0 = (short) (clipRect2.y0 + dy);
            dx = -dx;
            dy = -dy;
        }
        Transition trans = new Transition(delay, time, control, 0, dx, dy);
        startTask(trans);
    }

    public void doScreenState(int newState) {
        if (newState != screenState || newState == 2) {
            int delay = setScreenState(newState);
            addEvent(1, delay);
        }
    }

    /* JADX INFO: Access modifiers changed from: protected */
    public int setScreenState(int newState) {
        if (screenState == 0 && (newState == 2 || newState == 3)) {
            clearTasks();
            clearEvents();
        }
        screenState = newState;
        return 0;
    }

    public static final void startTask(Transition task) {
        taskList.addElement(task);
    }

    public static final void clearTasks() {
        taskList.removeAllElements();
    }

    public static final void finishTask(Transition task) {
        taskList.removeElement(task);
    }

    public static final void processTasks() {
        for (int i = 0; i < taskList.size(); i++) {
            Transition task = (Transition) taskList.elementAt(i);
            task.process();
        }
    }

    public static final void processEvents() {
        int i = 0;
        while (i < eventList.size()) {
            int[] eh = (int[]) eventList.elementAt(i);
            eh[1] = eh[1] - Application.lastFrameTime;
            if (eh[1] <= 0) {
                instance.handleEvent(eh[0]);
                eventList.removeElementAt(i);
                i--;
            }
            i++;
        }
    }

    public static final void addEvent(int event, int delay) {
        int[] eh = {event, delay};
        eventList.addElement(eh);
    }

    public static final void clearEvents() {
        int i = 0;
        while (i < eventList.size()) {
            int[] eh = (int[]) eventList.elementAt(i);
            if (eh[0] < 2) {
                eventList.removeElementAt(i);
                i--;
            }
            i++;
        }
    }
}
