package com.slg.j2me.lib.snd;

import android.media.MediaPlayer;
import android.media.SoundPool;
import com.slg.j2me.lib.sys.Application;
/* loaded from: classes.dex */
public class SoundBank {
    public static final int cDefaultVolume = 100;
    public static final int cNumSFXStreams = 8;
    private static int[] musicFiles;
    private static boolean musicLooping;
    private static boolean musicPaused;
    private static int musicVolume;
    private static int[] sfxFadeTimeCurrent;
    private static int[] sfxFadeTimeTotal;
    private static boolean[] sfxFadingOut;
    private static int[] sfxFiles;
    private static boolean[] sfxLooping;
    private static boolean[] sfxPaused;
    private static boolean[] sfxSavedLooping;
    private static int[] sfxSoundID;
    private static int[] sfxStreamID;
    private static int[] sfxVolume;
    private static SoundBank instance = null;
    public static boolean soundEnabled = true;
    private static int musicNumFiles = 0;
    private static int musicCurrent = -1;
    private static int sfxNumFiles = 0;
    private static int sfxSavedLoopsCallCount = 0;
    private static MediaPlayer musicPlayer = null;
    private static SoundPool sfxPool = null;

    public static void musicSetFiles(int[] audioFiles) {
        if (instance == null) {
            instance = new SoundBank();
        }
        musicFiles = audioFiles;
        musicVolume = 100;
        musicCurrent = -1;
        musicPaused = false;
        musicLooping = false;
        musicNumFiles = audioFiles.length;
        for (int i = 0; i < musicNumFiles; i++) {
        }
    }

    public static void sfxSetFiles(int[] audioFiles) {
        if (instance == null) {
            instance = new SoundBank();
        }
        sfxFiles = audioFiles;
        sfxNumFiles = audioFiles.length;
        for (int i = 0; i < sfxNumFiles; i++) {
        }
        sfxPool = new SoundPool(8, 3, 0);
        sfxStreamID = new int[sfxNumFiles];
        sfxSoundID = new int[sfxNumFiles];
        sfxVolume = new int[sfxNumFiles];
        sfxPaused = new boolean[sfxNumFiles];
        sfxLooping = new boolean[sfxNumFiles];
        sfxSavedLooping = new boolean[sfxNumFiles];
        sfxFadeTimeTotal = new int[sfxNumFiles];
        sfxFadeTimeCurrent = new int[sfxNumFiles];
        sfxFadingOut = new boolean[sfxNumFiles];
        for (int i2 = 0; i2 < sfxNumFiles; i2++) {
            sfxLoad(i2);
            sfxStreamID[i2] = 0;
            sfxVolume[i2] = 0;
            sfxPaused[i2] = false;
            sfxLooping[i2] = false;
            sfxSavedLooping[i2] = false;
            sfxFadeTimeTotal[i2] = 0;
        }
    }

    public static boolean musicLoad(int idx) {
        try {
            if (musicPlayer != null) {
                musicPlayer.reset();
                musicPlayer.release();
                musicPlayer = null;
            }
            musicPlayer = MediaPlayer.create(Application.instance, musicFiles[idx]);
            musicCurrent = idx;
            return true;
        } catch (IllegalArgumentException | Exception e) {
            musicCurrent = -1;
            return false;
        }
    }

    public static boolean sfxLoad(int idx) {
        try {
            sfxSoundID[idx] = sfxPool.load(Application.instance, sfxFiles[idx], 0);
            return true;
        } catch (IllegalArgumentException | Exception e) {
            return false;
        }
    }

    public static void shutdown() {
        if (musicPlayer != null) {
            musicPlayer.stop();
            musicPlayer.reset();
            musicPlayer.release();
            musicPlayer = null;
        }
        if (sfxPool != null) {
            for (int i = 0; i < sfxNumFiles; i++) {
                if (sfxStreamID[i] != 0) {
                    sfxPool.setLoop(sfxStreamID[i], 0);
                    sfxPool.setVolume(sfxStreamID[i], 0.0f, 0.0f);
                }
            }
            sfxPool.release();
            sfxPool = null;
            sfxSoundID = null;
            sfxStreamID = null;
        }
        musicCurrent = -1;
        Application.gc();
    }

    public static int musicGetCurrent() {
        return musicCurrent;
    }

    public static int musicGetVolume() {
        return musicVolume;
    }

    public static void musicPlay(int idx, boolean _looping, int volume) {
        if (soundEnabled) {
            if (musicCurrent != idx) {
                musicLoad(idx);
            }
            musicPlayer.start();
            musicPlayer.setLooping(_looping);
            float fVol = volume == 100 ? 1.0f : volume * 0.01f;
            musicPlayer.setVolume(fVol, fVol);
            musicCurrent = idx;
            musicVolume = volume;
            musicPaused = false;
            musicLooping = _looping;
        }
    }

    public static void sfxPlay(int idx, boolean _looping, int volume, int fpFadeInTime) {
        if (soundEnabled && sfxPool != null) {
            int id = sfxSoundID[idx];
            if (id != 0) {
                if (sfxLooping[idx] && sfxStreamID[idx] != 0) {
                    sfxPool.setLoop(sfxStreamID[idx], 0);
                }
                sfxPool.setVolume(sfxStreamID[idx], 0.0f, 0.0f);
                sfxVolume[idx] = volume;
                sfxFadeTimeTotal[idx] = fpFadeInTime;
                if (fpFadeInTime > 0) {
                    sfxFadeTimeCurrent[idx] = 0;
                    sfxFadingOut[idx] = false;
                    volume = 0;
                }
                float fVol = volume == 100 ? 1.0f : volume * 0.01f;
                int loopCount = _looping ? -1 : 0;
                if (_looping) {
                }
                sfxStreamID[idx] = sfxPool.play(id, fVol, fVol, 0, loopCount, 1.0f);
            }
            sfxPaused[idx] = false;
            sfxLooping[idx] = _looping;
        }
    }

    public static void musicStop() {
        if (musicPlayer != null) {
            musicPlayer.stop();
        }
        musicCurrent = -1;
    }

    public static void sfxStop(int idx, int fpFadeOutTime) {
        if (fpFadeOutTime > 0) {
            sfxFadeTimeTotal[idx] = fpFadeOutTime;
            sfxFadeTimeCurrent[idx] = 0;
            sfxFadingOut[idx] = true;
        } else if (sfxPool != null && sfxStreamID[idx] != 0) {
            sfxPool.setLoop(sfxStreamID[idx], 0);
            sfxPool.setVolume(sfxStreamID[idx], 0.0f, 0.0f);
            sfxStreamID[idx] = 0;
        }
    }

    public static void sfxStopAll() {
        if (sfxPool != null) {
            for (int i = 0; i < sfxNumFiles; i++) {
                if (sfxStreamID[i] != 0) {
                    sfxPool.setLoop(sfxStreamID[i], 0);
                    sfxPool.setVolume(sfxStreamID[i], 0.0f, 0.0f);
                    sfxStreamID[i] = 0;
                }
            }
        }
    }

    public static void sfxPause(int idx, boolean p) {
        if (sfxPool != null && sfxStreamID[idx] != 0) {
            if (p) {
                sfxPool.pause(sfxStreamID[idx]);
            } else {
                sfxPool.resume(sfxStreamID[idx]);
            }
            sfxPaused[idx] = p;
        }
    }

    public static boolean sfxIsPaused(int idx) {
        return sfxPaused[idx];
    }

    public static boolean sfxIsLooping(int idx) {
        return sfxLooping[idx] && sfxStreamID[idx] != 0;
    }

    public static void musicSetVolume(int vol) {
        musicVolume = vol;
        if (musicPlayer != null) {
            float fVol = vol == 100 ? 1.0f : vol * 0.01f;
            musicPlayer.setVolume(fVol, fVol);
        }
    }

    public static void sfxSetVolume(int idx, int vol) {
        if (sfxPool != null && sfxStreamID[idx] != 0) {
            sfxVolume[idx] = vol;
            if (sfxFadeTimeTotal[idx] == 0) {
                float fVol = vol == 100 ? 1.0f : vol * 0.01f;
                sfxPool.setVolume(sfxStreamID[idx], fVol, fVol);
            }
        }
    }

    public static void sfxSaveLoops() {
        sfxSavedLoopsCallCount++;
        if (sfxSavedLoopsCallCount <= 1) {
            for (int i = 0; i < sfxNumFiles; i++) {
                sfxSavedLooping[i] = sfxLooping[i] && !sfxPaused[i] && sfxStreamID[i] != 0 && (sfxFadeTimeTotal[i] <= 0 || !sfxFadingOut[i]);
            }
        }
    }

    public static void sfxRestoreLoops() {
        sfxSavedLoopsCallCount--;
        if (sfxSavedLoopsCallCount <= 0) {
            for (int i = 0; i < sfxNumFiles; i++) {
                if (sfxSavedLooping[i]) {
                    sfxPlay(i, true, 100, 0);
                    sfxSavedLooping[i] = false;
                }
            }
        }
    }

    public static void sfxClearSavedLoops() {
        for (int i = 0; i < sfxNumFiles; i++) {
            sfxSavedLooping[i] = false;
        }
        sfxSavedLoopsCallCount = 0;
    }

    public static void enableSound(boolean enabled) {
        soundEnabled = enabled;
        if (!soundEnabled) {
            musicStop();
            sfxStopAll();
        }
    }

    public static void process() {
        int dt = Application.fp_deltatime;
        for (int i = 0; i < sfxNumFiles; i++) {
            if (sfxFadeTimeTotal[i] > 0) {
                if (sfxFadingOut[i]) {
                    int[] iArr = sfxFadeTimeCurrent;
                    iArr[i] = iArr[i] + dt;
                    if (sfxFadeTimeCurrent[i] >= sfxFadeTimeTotal[i]) {
                        sfxFadeTimeTotal[i] = 0;
                        sfxStop(i, 0);
                    } else {
                        float fVol = 1.0f - (sfxFadeTimeCurrent[i] / sfxFadeTimeTotal[i]);
                        if (sfxVolume[i] < 100) {
                            fVol = sfxVolume[i] * fVol * 0.01f;
                        }
                        sfxPool.setVolume(sfxStreamID[i], fVol, fVol);
                    }
                } else {
                    int[] iArr2 = sfxFadeTimeCurrent;
                    iArr2[i] = iArr2[i] + dt;
                    if (sfxFadeTimeCurrent[i] >= sfxFadeTimeTotal[i]) {
                        sfxFadeTimeTotal[i] = 0;
                        float fVol2 = 1.0f;
                        if (sfxVolume[i] < 100) {
                            fVol2 = sfxVolume[i] * 0.01f;
                        }
                        sfxPool.setVolume(sfxStreamID[i], fVol2, fVol2);
                    } else {
                        float fVol3 = sfxFadeTimeCurrent[i] / sfxFadeTimeTotal[i];
                        if (sfxVolume[i] < 100) {
                            fVol3 = sfxVolume[i] * fVol3 * 0.01f;
                        }
                        sfxPool.setVolume(sfxStreamID[i], fVol3, fVol3);
                    }
                }
            }
        }
    }
}
