package com.slg.j2me.lib.sys;

import android.util.DisplayMetrics;
import com.slg.j2me.lib.gfx.BaseScreen;
import com.slg.j2me.lib.snd.SoundBank;
import java.io.InputStream;
import javax.microedition.lcdui.Display;
import javax.microedition.midlet.MIDlet;
/* loaded from: classes.dex */
public abstract class Application extends MIDlet {
    public static final String GFX_16B_EXTENSION = "_16b";
    public static final String GFX_ATI_EXTENSION = "_ati";
    public static final String GFX_DEFAULT_EXTENSION = "_16b";
    public static final String GFX_PVR_EXTENSION = "_pvr";
    public static final String TAG = "@application-package@";
    public static Application instance = null;
    public static Display display = null;
    public static String strResourcePackage = null;
    public static boolean loaded = false;
    public static boolean applicationPaused = false;
    public static boolean isLoading = false;
    public static long startingMemory = Runtime.getRuntime().freeMemory();
    public static boolean hasFocus = false;
    public static String GFX_EXTENSION = "_16b";
    public static boolean isPVR = false;
    public static boolean isATI = false;
    public static boolean crapDevice = false;
    public static long timeLastFrame = System.currentTimeMillis();
    public static int lastFrameTime = 20;
    public static int fp_deltatime = 0;

    public abstract void load();

    @Override // javax.microedition.midlet.MIDlet
    public abstract void pauseApp();

    public abstract void process();

    @Override // javax.microedition.midlet.MIDlet
    public abstract void startApp();

    public Application() {
        instance = this;
        display = Display.getDisplay(this);
        printMemoryStatus();
    }

    public static void printMemoryStatus() {
        gc();
        Runtime.getRuntime().freeMemory();
    }

    @Override // javax.microedition.midlet.MIDlet
    public void checkCrapDevice() {
        DisplayMetrics metrics = new DisplayMetrics();
        getWindowManager().getDefaultDisplay().getMetrics(metrics);
        int resX = (int) (metrics.widthPixels * metrics.density);
        int resY = (int) (metrics.heightPixels * metrics.density);
        if (resX <= 480 || resY <= 320) {
            crapDevice = true;
        } else {
            crapDevice = false;
        }
    }

    /* JADX INFO: Access modifiers changed from: protected */
    public final void backgroundLoad() {
        load();
        loaded = true;
        timeLastFrame = System.currentTimeMillis();
    }

    public static void setAppLoading() {
        isLoading = true;
    }

    public void processInternal() {
        int i;
        if (applicationPaused) {
            timeLastFrame = System.currentTimeMillis();
            return;
        }
        long time = System.currentTimeMillis();
        if (isLoading) {
            isLoading = false;
            timeLastFrame = time;
        }
        lastFrameTime = (int) (time - timeLastFrame);
        timeLastFrame = time;
        if (lastFrameTime < 10) {
            i = 10;
        } else {
            i = lastFrameTime > 250 ? 250 : lastFrameTime;
        }
        lastFrameTime = i;
        fp_deltatime = lastFrameTime * 66;
        SoundBank.process();
        if (hasFocus) {
            BaseScreen.beginInputProcessing();
            try {
                process();
            } catch (Exception e) {
                e.printStackTrace();
            }
            BaseScreen.endInputProcessing();
            BaseScreen.forcePaint();
        }
    }

    public static final void quit() {
        try {
            instance.destroyApp(true);
        } catch (Exception e) {
            e.printStackTrace();
        }
        instance.notifyDestroyed();
        instance = null;
    }

    public static InputStream openResourceAsStream(String name) {
        int dot = name.indexOf(".");
        if (dot == -1) {
            dot = name.length();
        }
        String basename = name.substring(0, dot);
        int resID = instance.getResources().getIdentifier(strResourcePackage + ":raw" + basename, null, null);
        if (resID == 0 && (resID = instance.getResources().getIdentifier(strResourcePackage + ":raw" + basename + GFX_EXTENSION, null, null)) == 0) {
            resID = instance.getResources().getIdentifier(strResourcePackage + ":raw" + basename + "_16b", null, null);
        }
        try {
            InputStream is = instance.getResources().openRawResource(resID);
            return is;
        } catch (Exception e) {
            return null;
        }
    }

    public static final void gc() {
        System.gc();
    }

    public static final String formatNumber(int num, int length, char blank) {
        String s = "";
        int i = 1;
        for (int j = 1; j < length; j++) {
            if (num / i < 10) {
                s = s + blank;
            }
            i *= 10;
        }
        return num == 0 ? s + blank : s + num;
    }
}
