package com.slg.j2me.lib.util;

import com.slg.j2me.lib.sys.FixedPoint;
import java.io.DataInputStream;
import java.io.DataOutputStream;
import java.io.IOException;
/* loaded from: classes.dex */
public class BitVector {
    private int m_size = 0;
    private int[] m_array = null;

    public BitVector(int size, int[] data) {
        resize(size);
        setData(data);
    }

    public BitVector(int size) {
        resize(size);
    }

    public String toString() {
        String ret = new String();
        if (this.m_array != null) {
            for (int i = this.m_array.length - 1; i >= 0; i--) {
                ret = ret.concat(FixedPoint.maskToString(this.m_array[i], 32)).concat(" ");
            }
        }
        return ret;
    }

    public void resize(int size) {
        int newSize;
        if (this.m_size != size) {
            this.m_size = size;
            if (size > 0) {
                newSize = ((size - 1) / 32) + 1;
            } else {
                newSize = 0;
                this.m_array = null;
            }
            if (newSize > 0) {
                int[] newarray = new int[newSize];
                int min = newSize < (this.m_array != null ? this.m_array.length : 0) ? newSize : this.m_array != null ? this.m_array.length : 0;
                for (int i = 0; i < min; i++) {
                    newarray[i] = this.m_array[i];
                }
                this.m_array = newarray;
            }
        }
    }

    public void clear() {
        for (int i = 0; i < this.m_array.length; i++) {
            this.m_array[i] = 0;
        }
    }

    public void setBit(int bit) {
        int[] iArr = this.m_array;
        int i = bit >> 5;
        iArr[i] = iArr[i] | (1 << (bit & 31));
    }

    public boolean isBitSet(int bit) {
        return (this.m_array[bit >> 5] & (1 << (bit & 31))) != 0;
    }

    public void flipBit(int bit) {
        int[] iArr = this.m_array;
        int i = bit >> 5;
        iArr[i] = iArr[i] ^ (1 << (bit & 31));
    }

    public void clearBit(int bit) {
        int[] iArr = this.m_array;
        int i = bit >> 5;
        iArr[i] = iArr[i] & ((1 << (bit & 31)) ^ (-1));
    }

    public void setData(int[] data) {
        for (int i = 0; i < data.length; i++) {
            this.m_array[i] = data[i];
        }
    }

    public int[] getData() {
        return this.m_array;
    }

    public int size() {
        return this.m_size;
    }

    public boolean anySet() {
        for (int i = 0; i < this.m_array.length; i++) {
            if (this.m_array[i] != 0) {
                return true;
            }
        }
        return false;
    }

    public boolean noneSet() {
        for (int i = 0; i < this.m_array.length; i++) {
            if (this.m_array[i] != 0) {
                return false;
            }
        }
        return true;
    }

    public int getNextSetBit(int from) {
        for (int i = from; i < this.m_size; i++) {
            if (isBitSet(i)) {
                return i;
            }
        }
        return -1;
    }

    public void performOR(BitVector rhs) {
        int[] rhsData = rhs.getData();
        for (int i = 0; i < this.m_array.length; i++) {
            int[] iArr = this.m_array;
            iArr[i] = iArr[i] | rhsData[i];
        }
    }

    public void performAND(BitVector rhs) {
        int[] rhsData = rhs.getData();
        for (int i = 0; i < this.m_array.length; i++) {
            int[] iArr = this.m_array;
            iArr[i] = iArr[i] & rhsData[i];
        }
    }

    public void performXOR(BitVector rhs) {
        int[] rhsData = rhs.getData();
        for (int i = 0; i < this.m_array.length; i++) {
            int[] iArr = this.m_array;
            iArr[i] = iArr[i] ^ rhsData[i];
        }
    }

    public void inverseIntersection(BitVector rhs) {
        performXOR(rhs);
        performAND(rhs);
    }

    public void load(DataInputStream stream) throws IOException {
        int size = stream.readInt();
        resize(size);
        for (int i = 0; i < this.m_array.length; i++) {
            this.m_array[i] = stream.readInt();
        }
    }

    public void save(DataOutputStream stream) throws IOException {
        stream.writeInt(this.m_size);
        for (int i = 0; i < this.m_array.length; i++) {
            stream.writeInt(this.m_array[i]);
        }
    }
}
