package javax.microedition.lcdui;

import android.graphics.Bitmap;
import android.graphics.BitmapFactory;
import android.graphics.Canvas;
import android.graphics.Paint;
import com.slg.j2me.lib.sys.Application;
import java.io.DataInputStream;
import java.io.IOException;
import java.io.InputStream;
import java.nio.ByteBuffer;
import java.util.Vector;
/* loaded from: classes.dex */
public class ImageLoader {
    public static final boolean pow2TexturesOnly = true;
    public static final boolean squareTexturesOnly = false;
    private static Vector vecImagePFFilename = new Vector();
    private static Vector vecImagePFFormat = new Vector();

    public static void setImagePixelFormat(String filename, Bitmap.Config pixelformat) {
        vecImagePFFilename.addElement(filename);
        vecImagePFFormat.addElement(pixelformat);
    }

    public static Bitmap.Config getImagePixelFormat(String filename) {
        for (int i = 0; i < vecImagePFFilename.size(); i++) {
            String str = (String) vecImagePFFilename.elementAt(i);
            if (str.equals(filename)) {
                return (Bitmap.Config) vecImagePFFormat.elementAt(i);
            }
        }
        return null;
    }

    private static int nearestPow2(int size) {
        for (int i = 0; i < 16; i++) {
            if ((1 << i) >= size) {
                return 1 << i;
            }
        }
        return 16;
    }

    private static int reverseByteOrder(int val) {
        return ((val >> 24) & 255) | (((val >> 16) & 255) << 8) | (((val >> 8) & 255) << 16) | ((val & 255) << 24);
    }

    public static j2meImage createImage(String name) {
        int dot = name.indexOf(".");
        String basename = name.substring(0, dot);
        name.substring(dot, name.length());
        int resID = Application.instance.getResources().getIdentifier(Application.strResourcePackage + ":raw" + basename, null, null);
        if (resID == 0 && (resID = Application.instance.getResources().getIdentifier(Application.strResourcePackage + ":raw" + basename + Application.GFX_EXTENSION, null, null)) == 0) {
            resID = Application.instance.getResources().getIdentifier(Application.strResourcePackage + ":raw" + basename + "_16b", null, null);
        }
        j2meImage img = null;
        try {
            InputStream is = Application.openResourceAsStream(name);
            if (is != null) {
                DataInputStream dis = new DataInputStream(is);
                String sFileType = "";
                for (int i = 0; i < 4; i++) {
                    sFileType = sFileType + ((char) dis.readByte());
                }
                if (sFileType.endsWith("PNG")) {
                    img = loadPNG(name, resID);
                } else if (sFileType.endsWith("RAW")) {
                    img = loadRAW(dis, resID);
                } else if (sFileType.startsWith("DDS")) {
                    img = loadATC(dis, resID);
                } else {
                    img = loadPVR(dis, resID);
                }
                is.close();
            }
        } catch (Exception e) {
            e.printStackTrace();
        }
        if (img != null) {
            img.filename = name;
        }
        return img;
    }

    public static j2meImage loadPNG(String name, int resID) throws IOException {
        Bitmap bitmap;
        Bitmap origImg = BitmapFactory.decodeResource(Application.instance.getResources(), resID);
        int w = origImg.getWidth();
        int h = origImg.getHeight();
        Bitmap.Config pixelformat = getImagePixelFormat(name);
        int pow2_width = nearestPow2(w);
        int pow2_height = nearestPow2(h);
        if (pixelformat == null) {
            if (Application.isPVR) {
                pixelformat = Bitmap.Config.ARGB_8888;
            } else {
                pixelformat = origImg.hasAlpha() ? Bitmap.Config.ARGB_4444 : Bitmap.Config.RGB_565;
            }
        }
        if (pow2_width == w && pow2_height == h && pixelformat == Bitmap.Config.ARGB_8888) {
            bitmap = origImg;
        } else {
            bitmap = Bitmap.createBitmap(pow2_width, pow2_height, pixelformat);
            Canvas canvas = new Canvas(bitmap);
            canvas.drawBitmap(origImg, 0.0f, 0.0f, (Paint) null);
        }
        j2meImage img = new j2meImage(bitmap, resID);
        img.origWidth = w;
        img.origHeight = h;
        img.ooWidth = 1.0f / img.bitmap.getWidth();
        img.ooHeight = 1.0f / img.bitmap.getHeight();
        return img;
    }

    public static j2meImage loadATC(DataInputStream dis, int resID) throws IOException {
        int w = glGraphics.cMaxLines;
        int h = glGraphics.cMaxLines;
        int compressedFormat = 0;
        char[] fourcc = new char[4];
        for (int i = 1; i < 32; i++) {
            int val = dis.readInt();
            if (i == 3) {
                h = reverseByteOrder(val);
            }
            if (i == 4) {
                w = reverseByteOrder(val);
            }
            if (i == 21) {
                fourcc[0] = (char) ((val >> 24) & 255);
                fourcc[1] = (char) ((val >> 16) & 255);
                fourcc[2] = (char) ((val >> 8) & 255);
                fourcc[3] = (char) (val & 255);
            }
        }
        String sFourCC = "" + fourcc[0] + fourcc[1] + fourcc[2] + fourcc[3];
        if (sFourCC.equals("ATC ")) {
            compressedFormat = 35986;
        }
        if (sFourCC.equals("ATCA")) {
            compressedFormat = 35987;
        }
        if (sFourCC.equals("ATCI")) {
            compressedFormat = 34798;
        }
        return loadCompressedTexture(dis, resID, w, h, compressedFormat);
    }

    public static j2meImage loadPVR(DataInputStream dis, int resID) throws IOException {
        int fmt;
        int h = glGraphics.cMaxLines;
        int compressedFormat = 0;
        int i = -1;
        int w = 512;
        int i2 = 1;
        while (i2 < 13) {
            int val = dis.readInt();
            if (i2 == 1) {
                int w2 = reverseByteOrder(val);
                w = w2;
            }
            if (i2 == 2) {
                int h2 = reverseByteOrder(val);
                h = h2;
            }
            int fmt2 = i2 == 4 ? reverseByteOrder(val) : i;
            int fmt3 = i2 + 1;
            i2 = fmt3;
            i = fmt2;
        }
        boolean alpha = false;
        switch (i) {
            case 19:
                compressedFormat = 32856;
                alpha = false;
                fmt = 33635;
                break;
            case 32784:
                compressedFormat = 32856;
                alpha = true;
                fmt = 32819;
                break;
            case 32785:
                compressedFormat = 32856;
                alpha = true;
                fmt = 32820;
                break;
            case 32786:
                compressedFormat = 32856;
                alpha = true;
                fmt = 5121;
                break;
            case 32792:
                compressedFormat = 35843;
                alpha = true;
                fmt = -1;
                break;
            case 32793:
                compressedFormat = 35842;
                alpha = true;
                fmt = -1;
                break;
            default:
                fmt = -1;
                break;
        }
        j2meImage img = loadCompressedTexture(dis, resID, w, h, compressedFormat);
        if (img != null) {
            img.alpha = alpha;
            img.pixelFormat = fmt;
        }
        return img;
    }

    public static j2meImage loadRAW(DataInputStream dis, int resID) throws IOException {
        dis.readInt();
        int w = dis.readInt();
        int h = dis.readInt();
        return loadCompressedTexture(dis, resID, w, h, 32856);
    }

    public static j2meImage loadCompressedTexture(DataInputStream dis, int resID, int w, int h, int compressedFormat) throws IOException {
        byte[] data = new byte[dis.available()];
        dis.read(data);
        ByteBuffer compressedTexture = ByteBuffer.wrap(data);
        compressedTexture.position(0);
        j2meImage img = new j2meImage(compressedTexture, resID);
        img.compressedFormat = compressedFormat;
        img.origWidth = w;
        img.origHeight = h;
        img.ooWidth = 1.0f / w;
        img.ooHeight = 1.0f / h;
        return img;
    }
}
