package javax.microedition.midlet;

import android.content.Context;
import com.slg.j2me.lib.sys.FixedPoint;
import javax.microedition.khronos.opengles.GL10;
import javax.microedition.lcdui.game.BlendMode;
import javax.microedition.lcdui.game.Line2D;
import javax.microedition.lcdui.game.Sprite;
import javax.microedition.lcdui.game.SpriteEx;
import javax.microedition.lcdui.game.Triangle2D;
/* loaded from: classes.dex */
public class BatchGLRenderer extends SimpleGLRenderer {
    public BatchGLRenderer(Context context, GLGameView gameview) {
        super(context, gameview);
    }

    @Override // javax.microedition.midlet.SimpleGLRenderer, android.opengl.GLSurfaceView.Renderer
    public void onDrawFrame(GL10 gl) {
        this.mGameView.process();
        if (this.vecPending != null) {
            gl.glMatrixMode(5888);
            last_blend_mode = -1;
            setGLBlendMode(gl, 0);
            this.glState = 0;
            int i = 0;
            while (i < this.vecPending.size()) {
                Object obj = this.vecPending.elementAt(i);
                if (obj instanceof Sprite) {
                    getSpriteBatchLength(i);
                    drawSprite(gl, (Sprite) obj);
                } else if (obj instanceof SpriteEx) {
                    int batch_length = getSpriteExBatchLength(i);
                    if (batch_length == 1) {
                        drawSpriteEx(gl, (SpriteEx) obj);
                    } else {
                        i += drawSpriteExs(gl, i, batch_length) - 1;
                    }
                } else if (obj instanceof Line2D) {
                    int batch_length2 = getLineBatchLength(i);
                    if (batch_length2 == 1) {
                        drawLine2D(gl, (Line2D) obj);
                    } else {
                        i += drawLines2D(gl, i, batch_length2) - 1;
                    }
                } else if (obj instanceof Triangle2D) {
                    int batch_length3 = getTriangleBatchLength(i);
                    if (batch_length3 == 1) {
                        drawTriangle2D(gl, (Triangle2D) obj);
                    } else {
                        i += drawTriangles2D(gl, i, batch_length3) - 1;
                    }
                } else if (obj instanceof BlendMode) {
                    setGLBlendMode(gl, ((BlendMode) obj).blendMode);
                }
                i++;
            }
        }
    }

    private int getLineBatchLength(int start) {
        Line2D line = (Line2D) this.vecPending.elementAt(start);
        int last_colour = line.colour;
        int last_x = line.x1;
        int last_y = line.y1;
        int size = this.vecPending.size();
        for (int i = start + 1; i < size; i++) {
            Object obj = this.vecPending.elementAt(i);
            if (obj instanceof Line2D) {
                Line2D line2 = (Line2D) obj;
                if (line2.colour != last_colour || line2.x0 != last_x || line2.y0 != last_y) {
                    return i - start;
                }
                last_x = line2.x1;
                last_y = line2.y1;
            } else {
                return i - start;
            }
        }
        return 1;
    }

    private int getTriangleBatchLength(int start) {
        Triangle2D tri = (Triangle2D) this.vecPending.elementAt(start);
        int last_colour = tri.colour;
        int size = this.vecPending.size();
        for (int i = start + 1; i < size; i++) {
            Object obj = this.vecPending.elementAt(i);
            if (obj instanceof Triangle2D) {
                Triangle2D tri2 = (Triangle2D) obj;
                if (tri2.colour != last_colour) {
                    return i - start;
                }
            } else {
                return i - start;
            }
        }
        return 1;
    }

    private int getSpriteBatchLength(int start) {
        Sprite spr = (Sprite) this.vecPending.elementAt(start);
        int texid = spr.image.resourceID;
        int col = spr.c;
        int size = this.vecPending.size();
        for (int i = start + 1; i < size; i++) {
            Object obj = this.vecPending.elementAt(i);
            if (obj instanceof Sprite) {
                Sprite spr2 = (Sprite) obj;
                if (spr2.image.resourceID != texid || spr2.c != col) {
                    return i - start;
                }
            } else {
                return i - start;
            }
        }
        return 1;
    }

    private int getSpriteExBatchLength(int start) {
        SpriteEx spr = (SpriteEx) this.vecPending.elementAt(start);
        int texid = spr.image.resourceID;
        int col = spr.c;
        int size = this.vecPending.size();
        for (int i = start + 1; i < size; i++) {
            Object obj = this.vecPending.elementAt(i);
            if (obj instanceof SpriteEx) {
                SpriteEx spr2 = (SpriteEx) obj;
                if (spr2.image.resourceID != texid || spr2.c != col) {
                    return i - start;
                }
            } else {
                return i - start;
            }
        }
        return 1;
    }

    private int drawLines2D(GL10 gl, int start, int batch_length) {
        if (this.glState != 2) {
            setGLState(gl, 2);
        }
        Line2D line = (Line2D) this.vecPending.elementAt(start);
        setGLColor(gl, line.colour);
        if (batch_length + 1 > cMaxPolygonsPerDraw * 3) {
            batch_length = (cMaxPolygonsPerDraw * 3) - 1;
        }
        line_pts[0] = line.x0;
        line_pts[1] = this.viewHeight - line.y0;
        line_pts[2] = 0.0f;
        int i = 0;
        int index = 3;
        while (i < batch_length) {
            Line2D line2 = (Line2D) this.vecPending.elementAt(start + i);
            int index2 = index + 1;
            line_pts[index] = line2.x1;
            int index3 = index2 + 1;
            line_pts[index2] = this.viewHeight - line2.y1;
            line_pts[index3] = 0.0f;
            i++;
            index = index3 + 1;
        }
        int indices = index / 3;
        vertexBuffer.position(0);
        vertexBuffer.put(line_pts, 0, index);
        vertexBuffer.position(0);
        gl.glVertexPointer(3, 5126, 0, vertexBuffer);
        gl.glDrawArrays(3, 0, indices);
        return indices - 1;
    }

    private int drawTriangles2D(GL10 gl, int start, int batch_length) {
        Triangle2D triangle = (Triangle2D) this.vecPending.elementAt(start);
        if (this.glState != 2) {
            setGLState(gl, 2);
        }
        setGLColor(gl, triangle.colour);
        if (batch_length > cMaxPolygonsPerDraw) {
            batch_length = cMaxPolygonsPerDraw;
        }
        int i = 0;
        int index = 0;
        while (i < batch_length) {
            Triangle2D triangle2 = (Triangle2D) this.vecPending.elementAt(start + i);
            int index2 = index + 1;
            triangle_pts[index] = triangle2.x0;
            int index3 = index2 + 1;
            triangle_pts[index2] = this.viewHeight - triangle2.y0;
            int index4 = index3 + 1;
            triangle_pts[index3] = 0.0f;
            int index5 = index4 + 1;
            triangle_pts[index4] = triangle2.x1;
            int index6 = index5 + 1;
            triangle_pts[index5] = this.viewHeight - triangle2.y1;
            int index7 = index6 + 1;
            triangle_pts[index6] = 0.0f;
            int index8 = index7 + 1;
            triangle_pts[index7] = triangle2.x2;
            int index9 = index8 + 1;
            triangle_pts[index8] = this.viewHeight - triangle2.y2;
            triangle_pts[index9] = 0.0f;
            i++;
            index = index9 + 1;
        }
        vertexBuffer.position(0);
        vertexBuffer.put(triangle_pts, 0, index);
        vertexBuffer.position(0);
        gl.glVertexPointer(3, 5126, 0, vertexBuffer);
        gl.glDrawArrays(4, 0, index / 3);
        return index / 9;
    }

    private int drawSprites(GL10 gl, int start, int batch_length) {
        Sprite spr = (Sprite) this.vecPending.elementAt(start);
        if (this.glState != 3) {
            setGLState(gl, 3);
        }
        setGLColor(gl, spr.c);
        if (setGLTexture(gl, spr.image)) {
            float oo_width = spr.image.ooWidth;
            float oo_height = spr.image.ooHeight;
            int uv_index = 0;
            int index = 0;
            for (int i = 0; i < batch_length; i++) {
                Sprite spr2 = (Sprite) this.vecPending.elementAt(start + i);
                float u0 = spr2.u * oo_width;
                float v0 = spr2.v * oo_height;
                float u1 = (spr2.u + spr2.w) * oo_width;
                float v1 = (spr2.v + spr2.h) * oo_height;
                int index2 = index + 1;
                triangle_pts[index] = spr2.x;
                int index3 = index2 + 1;
                triangle_pts[index2] = this.viewHeight - spr2.y;
                int index4 = index3 + 1;
                triangle_pts[index3] = 0.0f;
                int uv_index2 = uv_index + 1;
                line_pts[uv_index] = u0;
                int uv_index3 = uv_index2 + 1;
                line_pts[uv_index2] = v0;
                int index5 = index4 + 1;
                triangle_pts[index4] = spr2.x + spr2.w;
                int index6 = index5 + 1;
                triangle_pts[index5] = this.viewHeight - spr2.y;
                int index7 = index6 + 1;
                triangle_pts[index6] = 0.0f;
                int uv_index4 = uv_index3 + 1;
                line_pts[uv_index3] = u1;
                int uv_index5 = uv_index4 + 1;
                line_pts[uv_index4] = v0;
                int index8 = index7 + 1;
                triangle_pts[index7] = spr2.x + spr2.w;
                int index9 = index8 + 1;
                triangle_pts[index8] = (this.viewHeight - spr2.y) - spr2.h;
                int index10 = index9 + 1;
                triangle_pts[index9] = 0.0f;
                int uv_index6 = uv_index5 + 1;
                line_pts[uv_index5] = u1;
                int uv_index7 = uv_index6 + 1;
                line_pts[uv_index6] = v1;
                int index11 = index10 + 1;
                triangle_pts[index10] = spr2.x;
                int index12 = index11 + 1;
                triangle_pts[index11] = this.viewHeight - spr2.y;
                int index13 = index12 + 1;
                triangle_pts[index12] = 0.0f;
                int uv_index8 = uv_index7 + 1;
                line_pts[uv_index7] = u0;
                int uv_index9 = uv_index8 + 1;
                line_pts[uv_index8] = v0;
                int index14 = index13 + 1;
                triangle_pts[index13] = spr2.x + spr2.w;
                int index15 = index14 + 1;
                triangle_pts[index14] = (this.viewHeight - spr2.y) - spr2.h;
                int index16 = index15 + 1;
                triangle_pts[index15] = 0.0f;
                int uv_index10 = uv_index9 + 1;
                line_pts[uv_index9] = u1;
                int uv_index11 = uv_index10 + 1;
                line_pts[uv_index10] = v1;
                int index17 = index16 + 1;
                triangle_pts[index16] = spr2.x;
                int index18 = index17 + 1;
                triangle_pts[index17] = (this.viewHeight - spr2.y) - spr2.h;
                index = index18 + 1;
                triangle_pts[index18] = 0.0f;
                int uv_index12 = uv_index11 + 1;
                line_pts[uv_index11] = u0;
                uv_index = uv_index12 + 1;
                line_pts[uv_index12] = v1;
            }
            vertexBuffer.position(0);
            vertexBuffer.put(triangle_pts, 0, index);
            vertexBuffer.position(0);
            gl.glVertexPointer(3, 5126, 0, vertexBuffer);
            uvBuffer.position(0);
            uvBuffer.put(line_pts, 0, uv_index);
            uvBuffer.position(0);
            gl.glTexCoordPointer(2, 5126, 0, uvBuffer);
            gl.glDrawArrays(4, 0, index / 3);
            return index / 18;
        }
        return batch_length;
    }

    private int drawSpriteExs(GL10 gl, int start, int batch_length) {
        if (this.glState != 3) {
            setGLState(gl, 3);
        }
        SpriteEx spr = (SpriteEx) this.vecPending.elementAt(start);
        setGLColor(gl, spr.c);
        if (setGLTexture(gl, spr.image)) {
            float oo_width = spr.image.ooWidth;
            float oo_height = spr.image.ooHeight;
            if (batch_length * 2 > cMaxPolygonsPerDraw) {
                batch_length = cMaxPolygonsPerDraw / 2;
            }
            int uv_index = 0;
            int index = 0;
            for (int i = 0; i < batch_length; i++) {
                SpriteEx spr2 = (SpriteEx) this.vecPending.elementAt(start + i);
                float u0 = spr2.u * oo_width;
                float v0 = spr2.v * oo_height;
                float u1 = (spr2.u + spr2.w) * oo_width;
                float v1 = (spr2.v + spr2.h) * oo_height;
                if (spr2.image.compressedFormat == 35842 || spr2.image.compressedFormat == 32856) {
                    v0 = 1.0f - v0;
                    v1 = 1.0f - v1;
                }
                float scale = spr2.s * 1.5258789E-5f * 0.5f;
                float rx = spr2.w * scale;
                float ry = spr2.h * scale;
                float x = spr2.x;
                float y = this.viewHeight - spr2.y;
                if (spr2.trans == 1) {
                    u0 = u1;
                    u1 = u0;
                }
                float sinr = FixedPoint.sinLut(spr2.r) * 1.5258789E-5f;
                float cosr = FixedPoint.sinLut(spr2.r + 4194304) * 1.5258789E-5f;
                float xsize_cosr = rx * cosr;
                float xsize_sinr = rx * sinr;
                float ysize_cosr = ry * cosr;
                float ysize_sinr = ry * sinr;
                float p0x = (-xsize_cosr) + ysize_sinr;
                float p0y = (-ysize_cosr) + (-xsize_sinr);
                float p1x = xsize_cosr + ysize_sinr;
                float p1y = (-ysize_cosr) + xsize_sinr;
                float p2x = xsize_cosr + (-ysize_sinr);
                float p2y = ysize_cosr + xsize_sinr;
                float p3x = (-xsize_cosr) + (-ysize_sinr);
                float p3y = ysize_cosr + (-xsize_sinr);
                int index2 = index + 1;
                triangle_pts[index] = x + p0x;
                int index3 = index2 + 1;
                triangle_pts[index2] = y - p0y;
                int index4 = index3 + 1;
                triangle_pts[index3] = 0.0f;
                int uv_index2 = uv_index + 1;
                line_pts[uv_index] = u0;
                int uv_index3 = uv_index2 + 1;
                line_pts[uv_index2] = v0;
                int index5 = index4 + 1;
                triangle_pts[index4] = x + p1x;
                int index6 = index5 + 1;
                triangle_pts[index5] = y - p1y;
                int index7 = index6 + 1;
                triangle_pts[index6] = 0.0f;
                int uv_index4 = uv_index3 + 1;
                line_pts[uv_index3] = u1;
                int uv_index5 = uv_index4 + 1;
                line_pts[uv_index4] = v0;
                int index8 = index7 + 1;
                triangle_pts[index7] = x + p2x;
                int index9 = index8 + 1;
                triangle_pts[index8] = y - p2y;
                int index10 = index9 + 1;
                triangle_pts[index9] = 0.0f;
                int uv_index6 = uv_index5 + 1;
                line_pts[uv_index5] = u1;
                int uv_index7 = uv_index6 + 1;
                line_pts[uv_index6] = v1;
                int index11 = index10 + 1;
                triangle_pts[index10] = x + p0x;
                int index12 = index11 + 1;
                triangle_pts[index11] = y - p0y;
                int index13 = index12 + 1;
                triangle_pts[index12] = 0.0f;
                int uv_index8 = uv_index7 + 1;
                line_pts[uv_index7] = u0;
                int uv_index9 = uv_index8 + 1;
                line_pts[uv_index8] = v0;
                int index14 = index13 + 1;
                triangle_pts[index13] = x + p2x;
                int index15 = index14 + 1;
                triangle_pts[index14] = y - p2y;
                int index16 = index15 + 1;
                triangle_pts[index15] = 0.0f;
                int uv_index10 = uv_index9 + 1;
                line_pts[uv_index9] = u1;
                int uv_index11 = uv_index10 + 1;
                line_pts[uv_index10] = v1;
                int index17 = index16 + 1;
                triangle_pts[index16] = x + p3x;
                int index18 = index17 + 1;
                triangle_pts[index17] = y - p3y;
                index = index18 + 1;
                triangle_pts[index18] = 0.0f;
                int uv_index12 = uv_index11 + 1;
                line_pts[uv_index11] = u0;
                uv_index = uv_index12 + 1;
                line_pts[uv_index12] = v1;
            }
            vertexBuffer.position(0);
            vertexBuffer.put(triangle_pts, 0, index);
            vertexBuffer.position(0);
            gl.glVertexPointer(3, 5126, 0, vertexBuffer);
            uvBuffer.position(0);
            uvBuffer.put(line_pts, 0, uv_index);
            uvBuffer.position(0);
            gl.glTexCoordPointer(2, 5126, 0, uvBuffer);
            gl.glDrawArrays(4, 0, index / 3);
            return index / 18;
        }
        return batch_length;
    }
}
