package javax.microedition.midlet;

import android.content.Context;
import android.graphics.Bitmap;
import android.graphics.BitmapFactory;
import android.opengl.GLSurfaceView;
import android.opengl.GLUtils;
import com.slg.j2me.lib.gfx.BaseScreen;
import com.slg.j2me.lib.sys.FixedPoint;
import java.nio.ByteBuffer;
import java.nio.ByteOrder;
import java.nio.FloatBuffer;
import java.util.Vector;
import javax.microedition.khronos.egl.EGLConfig;
import javax.microedition.khronos.opengles.GL10;
import javax.microedition.khronos.opengles.GL11;
import javax.microedition.khronos.opengles.GL11Ext;
import javax.microedition.lcdui.game.BlendMode;
import javax.microedition.lcdui.game.Line2D;
import javax.microedition.lcdui.game.Sprite;
import javax.microedition.lcdui.game.SpriteEx;
import javax.microedition.lcdui.game.Triangle2D;
import javax.microedition.lcdui.j2meImage;
/* loaded from: classes.dex */
public class SimpleGLRenderer implements GLSurfaceView.Renderer {
    public static final int cGLStateLine = 2;
    public static final int cGLStateSprite = 1;
    public static final int cGLStateSpriteBatch = 3;
    public static final int cGLStateUnknown = 0;
    protected static FloatBuffer uvBuffer;
    protected static ByteBuffer uvbb;
    protected static ByteBuffer vbb;
    protected static FloatBuffer vertexBuffer;
    protected Context mContext;
    protected GLGameView mGameView;
    protected Vector vecPending;
    protected int viewHeight;
    protected int viewWidth;
    public static final int cMaxResID = 256;
    protected static int[] textureCache = new int[cMaxResID];
    public static int cMaxPolygonsPerDraw = 64;
    protected static float[] line_pts = new float[cMaxPolygonsPerDraw * 6];
    protected static float[] triangle_pts = new float[cMaxPolygonsPerDraw * 9];
    protected static BitmapFactory.Options sBitmapOptions = new BitmapFactory.Options();
    protected static int last_texture = -1;
    protected static int last_colour = 0;
    protected static int last_blend_mode = -1;
    protected static int[] uv_params = {-1, -1, -1, -1};
    protected int glState = 0;
    private int[] mTextureNameWorkspace = new int[1];

    public SimpleGLRenderer(Context context, GLGameView gameview) {
        sBitmapOptions.inPreferredConfig = Bitmap.Config.RGB_565;
        this.mContext = context;
        this.mGameView = gameview;
        initDynamicVertexBuffers();
    }

    public int[] getConfigSpec() {
        int[] configSpec = {12325, 0, 12344};
        return configSpec;
    }

    public void setSprites(Vector sprites) {
        this.vecPending = sprites;
    }

    public void initDynamicVertexBuffers() {
        vbb = ByteBuffer.allocateDirect(cMaxPolygonsPerDraw * 3 * 3 * 4);
        vbb.order(ByteOrder.nativeOrder());
        vertexBuffer = vbb.asFloatBuffer();
        uvbb = ByteBuffer.allocateDirect(cMaxPolygonsPerDraw * 3 * 2 * 4);
        uvbb.order(ByteOrder.nativeOrder());
        uvBuffer = uvbb.asFloatBuffer();
    }

    @Override // android.opengl.GLSurfaceView.Renderer
    public void onDrawFrame(GL10 gl) {
        this.mGameView.process();
        if (this.vecPending != null) {
            gl.glMatrixMode(5888);
            last_blend_mode = -1;
            setGLBlendMode(gl, 0);
            this.glState = 0;
            for (int i = 0; i < this.vecPending.size(); i++) {
                Object obj = this.vecPending.elementAt(i);
                if (obj instanceof Sprite) {
                    drawSprite(gl, (Sprite) obj);
                } else if (obj instanceof SpriteEx) {
                    drawSpriteEx(gl, (SpriteEx) obj);
                } else if (obj instanceof Line2D) {
                    drawLine2D(gl, (Line2D) obj);
                } else if (obj instanceof Triangle2D) {
                    drawTriangle2D(gl, (Triangle2D) obj);
                } else if (obj instanceof BlendMode) {
                    setGLBlendMode(gl, ((BlendMode) obj).blendMode);
                }
            }
        }
    }

    @Override // android.opengl.GLSurfaceView.Renderer
    public void onSurfaceChanged(GL10 gl, int width, int height) {
        gl.glViewport(0, 0, width, height);
        this.viewWidth = width;
        this.viewHeight = height;
        BaseScreen.displayWidth = width;
        BaseScreen.displayHeight = height;
        BaseScreen.visibleRect.w = (short) width;
        BaseScreen.visibleRect.h = (short) height;
        BaseScreen.setDefaultRes(480, 320);
        gl.glMatrixMode(5889);
        gl.glLoadIdentity();
        gl.glOrthof(0.0f, width, 0.0f, height, 0.0f, 1.0f);
        gl.glShadeModel(7424);
        gl.glEnable(3042);
        gl.glBlendFunc(770, 771);
        gl.glColor4x(65536, 65536, 65536, 65536);
        gl.glEnable(3553);
    }

    @Override // android.opengl.GLSurfaceView.Renderer
    public void onSurfaceCreated(GL10 gl, EGLConfig config) {
        gl.glHint(3152, 4353);
        gl.glClearColor(0.5f, 0.5f, 0.5f, 1.0f);
        gl.glShadeModel(7424);
        gl.glDisable(2929);
        gl.glDisable(3024);
        gl.glDisable(2896);
        gl.glClear(16640);
        invalidateCachedTextures();
    }

    public void shutdown(GL10 gl) {
        int[] textureToDelete = new int[1];
        for (int i = 0; i < 256; i++) {
            if (textureCache[i] != -1) {
                textureToDelete[0] = textureCache[i];
                gl.glDeleteTextures(1, textureToDelete, 0);
                textureCache[i] = -1;
            }
        }
    }

    public void deleteTexureFromCache(GL10 gl, int resID) {
        int index = resID & 65535;
        int[] textureToDelete = new int[1];
        if (textureCache[index] != -1) {
            textureToDelete[0] = textureCache[index];
            gl.glDeleteTextures(1, textureToDelete, 0);
            textureCache[index] = -1;
        }
    }

    protected int getTextureFromCache(int resID) {
        int index = resID & 65535;
        if (index < 0 || index >= 256) {
            return -1;
        }
        return textureCache[index];
    }

    protected void setTextureInCache(int resID, int texID) {
        int index = resID & 65535;
        if (index >= 0 && index < 256) {
            textureCache[index] = texID;
        }
    }

    public static void invalidateCachedTextures() {
        for (int i = 0; i < 256; i++) {
            textureCache[i] = -1;
        }
    }

    protected int loadTexureFromImage(Context context, GL10 gl, j2meImage image) {
        int textureName = -1;
        if (context != null && gl != null) {
            gl.glGenTextures(1, this.mTextureNameWorkspace, 0);
            textureName = this.mTextureNameWorkspace[0];
            gl.glBindTexture(3553, textureName);
            gl.glTexParameterf(3553, 10241, image.pointSampling ? 9728.0f : 9729.0f);
            gl.glTexParameterf(3553, 10240, image.pointSampling ? 9728.0f : 9729.0f);
            gl.glTexParameterf(3553, 10242, 33071.0f);
            gl.glTexParameterf(3553, 10243, 33071.0f);
            if (image.compressedTexture == null && (image.bitmap == null || image.bitmap.isRecycled())) {
                image.reload();
            }
            if (image.bitmap != null) {
                GLUtils.texImage2D(3553, 0, image.bitmap, 0);
                if (!image.isDynamic) {
                    image.bitmap.recycle();
                }
            } else if (image.compressedTexture != null) {
                if (image.compressedFormat == 32856) {
                    int fmt = image.alpha ? 6408 : 6407;
                    gl.glTexImage2D(3553, 0, fmt, image.getWidth(), image.getHeight(), 0, fmt, image.pixelFormat, image.compressedTexture);
                    int error = gl.glGetError();
                    if (error != 0) {
                    }
                } else {
                    gl.glCompressedTexImage2D(3553, 0, image.compressedFormat, image.getWidth(), image.getHeight(), 0, image.compressedTexture.capacity(), image.compressedTexture);
                }
                image.compressedTexture = null;
            } else {
                return -1;
            }
            int error2 = gl.glGetError();
            if (error2 != 0) {
            }
        }
        return textureName;
    }

    /* JADX INFO: Access modifiers changed from: protected */
    public void setGLState(GL10 gl, int new_state) {
        if (this.glState != new_state) {
            switch (this.glState) {
                case 0:
                    gl.glDisable(3553);
                    gl.glDisableClientState(32884);
                    gl.glDisableClientState(32888);
                    break;
                case 1:
                    gl.glDisable(3553);
                    break;
                case 2:
                    gl.glDisableClientState(32884);
                    break;
                case 3:
                    gl.glDisable(3553);
                    gl.glDisableClientState(32884);
                    gl.glDisableClientState(32888);
                    break;
            }
            switch (new_state) {
                case 1:
                    gl.glEnable(3553);
                    gl.glColor4f(1.0f, 1.0f, 1.0f, 1.0f);
                    gl.glTexEnvf(8960, 8704, 8448.0f);
                    last_texture = -1;
                    last_colour = -1;
                    uv_params[0] = -1;
                    uv_params[1] = -1;
                    uv_params[2] = -1;
                    uv_params[3] = -1;
                    break;
                case 2:
                    last_colour = -1;
                    gl.glColor4f(1.0f, 1.0f, 1.0f, 1.0f);
                    gl.glEnableClientState(32884);
                    break;
                case 3:
                    gl.glEnable(3553);
                    gl.glColor4f(1.0f, 1.0f, 1.0f, 1.0f);
                    last_texture = -1;
                    last_colour = -1;
                    gl.glEnableClientState(32884);
                    gl.glEnableClientState(32888);
                    break;
            }
            this.glState = new_state;
        }
    }

    /* JADX INFO: Access modifiers changed from: protected */
    public final void setGLBlendMode(GL10 gl, int blend_mode) {
        if (blend_mode != last_blend_mode) {
            switch (blend_mode) {
                case 0:
                    gl.glBlendFunc(770, 771);
                    break;
                case 1:
                    gl.glBlendFunc(770, 1);
                    break;
            }
            last_blend_mode = blend_mode;
        }
    }

    /* JADX INFO: Access modifiers changed from: protected */
    public final boolean setGLTexture(GL10 gl, j2meImage image) {
        if (image.invalidated) {
            deleteTexureFromCache(gl, image.resourceID);
            image.invalidated = false;
        }
        int textureID = getTextureFromCache(image.resourceID);
        if (textureID == -1) {
            textureID = loadTexureFromImage(this.mContext, gl, image);
            setTextureInCache(image.resourceID, textureID);
        }
        if (textureID == -1) {
            return false;
        }
        if (last_texture != textureID) {
            last_texture = textureID;
            gl.glBindTexture(3553, textureID);
        }
        return true;
    }

    /* JADX INFO: Access modifiers changed from: protected */
    public final void setGLColor(GL10 gl, int c) {
        if (c != last_colour) {
            gl.glColor4f(((c >> 16) & 255) / 255.0f, ((c >> 8) & 255) / 255.0f, (c & 255) / 255.0f, ((c >> 24) & 255) / 255.0f);
            last_colour = c;
        }
    }

    /* JADX INFO: Access modifiers changed from: protected */
    public void drawLine2D(GL10 gl, Line2D line) {
        if (this.glState != 2) {
            setGLState(gl, 2);
        }
        setGLColor(gl, line.colour);
        line_pts[0] = line.x0;
        line_pts[1] = this.viewHeight - line.y0;
        line_pts[2] = 0.0f;
        line_pts[3] = line.x1;
        line_pts[4] = this.viewHeight - line.y1;
        line_pts[5] = 0.0f;
        vertexBuffer.position(0);
        vertexBuffer.put(line_pts, 0, 6);
        vertexBuffer.position(0);
        gl.glVertexPointer(3, 5126, 0, vertexBuffer);
        gl.glDrawArrays(3, 0, 2);
    }

    /* JADX INFO: Access modifiers changed from: protected */
    public void drawTriangle2D(GL10 gl, Triangle2D triangle) {
        if (this.glState != 2) {
            setGLState(gl, 2);
        }
        setGLColor(gl, triangle.colour);
        triangle_pts[0] = triangle.x0;
        triangle_pts[1] = this.viewHeight - triangle.y0;
        triangle_pts[2] = 0.0f;
        triangle_pts[3] = triangle.x1;
        triangle_pts[4] = this.viewHeight - triangle.y1;
        triangle_pts[5] = 0.0f;
        triangle_pts[6] = triangle.x2;
        triangle_pts[7] = this.viewHeight - triangle.y2;
        triangle_pts[8] = 0.0f;
        vertexBuffer.position(0);
        vertexBuffer.put(triangle_pts, 0, 9);
        vertexBuffer.position(0);
        gl.glVertexPointer(3, 5126, 0, vertexBuffer);
        gl.glDrawArrays(5, 0, 3);
    }

    /* JADX INFO: Access modifiers changed from: protected */
    public void drawSprite(GL10 gl, Sprite spr) {
        if (this.glState != 1) {
            setGLState(gl, 1);
        }
        setGLColor(gl, spr.c);
        if (setGLTexture(gl, spr.image)) {
            boolean mirror = spr.trans == 1 || spr.trans == 6;
            boolean flip = spr.trans == 2 || spr.trans == 6;
            int u0 = mirror ? spr.u + spr.w : spr.u;
            int u1 = mirror ? -spr.w : spr.w;
            int v0 = flip ? spr.v : spr.v + spr.h;
            int v1 = flip ? spr.h : -spr.h;
            if (spr.image.compressedFormat == 35842 || spr.image.compressedFormat == 32856) {
                v0 = spr.image.getHeight() - v0;
                v1 = -v1;
            }
            if (uv_params[0] != u0 || uv_params[1] != v0 || uv_params[2] != u1 || uv_params[3] != v1) {
                uv_params[0] = u0;
                uv_params[1] = v0;
                uv_params[2] = u1;
                uv_params[3] = v1;
                ((GL11) gl).glTexParameteriv(3553, 35741, uv_params, 0);
            }
            ((GL11Ext) gl).glDrawTexfOES(spr.x, this.viewHeight - (spr.y + spr.dh), 0.0f, spr.dw, spr.dh);
        }
    }

    /* JADX INFO: Access modifiers changed from: protected */
    public void drawSpriteEx(GL10 gl, SpriteEx spr) {
        if (this.glState != 3) {
            setGLState(gl, 3);
        }
        setGLColor(gl, spr.c);
        if (setGLTexture(gl, spr.image)) {
            float oo_width = spr.image.ooWidth;
            float oo_height = spr.image.ooHeight;
            float u0 = spr.u * oo_width;
            float v0 = spr.v * oo_height;
            float u1 = (spr.u + spr.w) * oo_width;
            float v1 = (spr.v + spr.h) * oo_height;
            if (spr.image.compressedFormat == 35842 || spr.image.compressedFormat == 32856) {
                v0 = 1.0f - v0;
                v1 = 1.0f - v1;
            }
            float scale = spr.s * 1.5258789E-5f * 0.5f;
            float rx = spr.w * scale;
            float ry = spr.h * scale;
            float x = spr.x;
            float y = this.viewHeight - spr.y;
            if (spr.trans == 1) {
                u0 = u1;
                u1 = u0;
            }
            float sinr = FixedPoint.sinLut(spr.r) * 1.5258789E-5f;
            float cosr = FixedPoint.sinLut(spr.r + 4194304) * 1.5258789E-5f;
            float xsize_cosr = rx * cosr;
            float xsize_sinr = rx * sinr;
            float ysize_cosr = ry * cosr;
            float ysize_sinr = ry * sinr;
            float p0x = (-xsize_cosr) + ysize_sinr;
            float p0y = (-ysize_cosr) + (-xsize_sinr);
            float p1x = xsize_cosr + ysize_sinr;
            float p1y = (-ysize_cosr) + xsize_sinr;
            float p2x = xsize_cosr + (-ysize_sinr);
            float p2y = ysize_cosr + xsize_sinr;
            float p3x = (-xsize_cosr) + (-ysize_sinr);
            float p3y = ysize_cosr + (-xsize_sinr);
            int index = 0 + 1;
            triangle_pts[0] = x + p0x;
            int index2 = index + 1;
            triangle_pts[index] = y - p0y;
            int index3 = index2 + 1;
            triangle_pts[index2] = 0.0f;
            int uv_index = 0 + 1;
            line_pts[0] = u0;
            int uv_index2 = uv_index + 1;
            line_pts[uv_index] = v0;
            int index4 = index3 + 1;
            triangle_pts[index3] = x + p1x;
            int index5 = index4 + 1;
            triangle_pts[index4] = y - p1y;
            int index6 = index5 + 1;
            triangle_pts[index5] = 0.0f;
            int uv_index3 = uv_index2 + 1;
            line_pts[uv_index2] = u1;
            int uv_index4 = uv_index3 + 1;
            line_pts[uv_index3] = v0;
            int index7 = index6 + 1;
            triangle_pts[index6] = x + p2x;
            int index8 = index7 + 1;
            triangle_pts[index7] = y - p2y;
            int index9 = index8 + 1;
            triangle_pts[index8] = 0.0f;
            int uv_index5 = uv_index4 + 1;
            line_pts[uv_index4] = u1;
            int uv_index6 = uv_index5 + 1;
            line_pts[uv_index5] = v1;
            int index10 = index9 + 1;
            triangle_pts[index9] = x + p0x;
            int index11 = index10 + 1;
            triangle_pts[index10] = y - p0y;
            int index12 = index11 + 1;
            triangle_pts[index11] = 0.0f;
            int uv_index7 = uv_index6 + 1;
            line_pts[uv_index6] = u0;
            int uv_index8 = uv_index7 + 1;
            line_pts[uv_index7] = v0;
            int index13 = index12 + 1;
            triangle_pts[index12] = x + p2x;
            int index14 = index13 + 1;
            triangle_pts[index13] = y - p2y;
            int index15 = index14 + 1;
            triangle_pts[index14] = 0.0f;
            int uv_index9 = uv_index8 + 1;
            line_pts[uv_index8] = u1;
            int uv_index10 = uv_index9 + 1;
            line_pts[uv_index9] = v1;
            int index16 = index15 + 1;
            triangle_pts[index15] = x + p3x;
            int index17 = index16 + 1;
            triangle_pts[index16] = y - p3y;
            int index18 = index17 + 1;
            triangle_pts[index17] = 0.0f;
            int uv_index11 = uv_index10 + 1;
            line_pts[uv_index10] = u0;
            line_pts[uv_index11] = v1;
            vertexBuffer.position(0);
            vertexBuffer.put(triangle_pts, 0, index18);
            vertexBuffer.position(0);
            gl.glVertexPointer(3, 5126, 0, vertexBuffer);
            uvBuffer.position(0);
            uvBuffer.put(line_pts, 0, uv_index11 + 1);
            uvBuffer.position(0);
            gl.glTexCoordPointer(2, 5126, 0, uvBuffer);
            gl.glDrawArrays(4, 0, index18 / 3);
        }
    }
}
